! =================================================================================================================================
! MODULE       : pft_parameters
!
! CONTACT      : orchidee-help _at_ ipsl.jussieu.fr
!
! LICENCE      : IPSL (2011)
! This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
!
!>\BRIEF        This module initializes all the pft parameters in function of the
!!              number of vegetation types and of the values chosen by the user.
!!
!!\n DESCRIPTION:  This module allocates and initializes the pft parameters in function of the number of pfts
!!                 and the values of the parameters. \n
!!                 The number of PFTs is read in intersurf.f90 (subroutine intsurf_config). \n
!!                 Then we can initialize the parameters. \n
!!                 This module is the result of the merge of constantes_co2, constantes_veg, stomate_constants.\n
!!
!! RECENT CHANGE(S): Josefine Ghattas 2013 : The declaration part has been extracted and moved to module pft_parameters_var
!!
!! REFERENCE(S)	: None
!!
!! SVN          :
!! $HeadURL: $
!! $Date: 2015-02-22 16:18:16 +0100 (Sun, 22 Feb 2015) $
!! $Revision: 2555 $
!! \n
!_ ================================================================================================================================

MODULE pft_parameters

  USE pft_parameters_var
  USE constantes_mtc
  USE constantes
  USE ioipsl
  USE ioipsl_para 
  USE defprec
! tzjwb
  USE vertical_soil_var
  
  IMPLICIT NONE

CONTAINS
 !

!! ================================================================================================================================
!! SUBROUTINE   : pft_parameters_main
!!
!>\BRIEF          This subroutine initializes all the pft parameters in function of the
!! number of vegetation types chosen by the user.
!!
!! DESCRIPTION  : This subroutine is called after the reading of the number of PFTS and the options 
!!                activated by the user in the configuration files. (structure active_flags) \n
!!                The allocation is done just before reading the correspondence table  between PFTs and MTCs
!!                defined by the user in the configuration file.\n
!!                With the correspondence table, the subroutine can initialize the pft parameters in function
!!                of the flags activated (ok_sechiba, ok_stomate, ok_co2, routing, new_hydrol...) in order to
!!                optimize the memory allocation. \n
!!                If the number of PFTs and pft_to_mtc are not found, the standard configuration will be used
!!                (13 PFTs, PFT = MTC). \n 
!!                Some restrictions : the pft 1 can only be the bare soil and it is unique. \n
!!                Algorithm : Build new PFT from 13 generic-PFT or meta-classes.
!!                1. Read the number of PFTs in "run.def". If nothing is found, it is assumed that the user intend to use 
!!                   the standard of PFTs (13).
!!                2. Read the index vector in "run.def". The index vector associates one PFT to one meta-classe (or generic PFT).
!!                   When the association is done, the PFT defined by the user inherited the default values from the meta classe.
!!                   If nothing is found, it is assumed to use the standard index vector (PFT = MTC).
!!                3. Check consistency
!!                4. Memory allocation and initialization.
!!                5. The parameters are read in the configuration file in intsurf_config (intersurf module).
!!
!! RECENT CHANGE(S): None
!!
!! MAIN OUTPUT VARIABLE(S): None
!!
!! REFERENCE(S) : None
!!
!! FLOWCHART    : None
!! \n
!_ ================================================================================================================================

 SUBROUTINE pft_parameters_main(active_flags)

   IMPLICIT NONE

   !! 0. Variables and parameters declaration

   !! 0.1 Input variables 

   TYPE(control_type),INTENT(in) :: active_flags   !! What parts of the code are activated ? (true/false)
   
   !! 0.4 Local variables  

   INTEGER(i_std) :: j                             !! Index (unitless)

!_ ================================================================================================================================ 
   
   !
   ! PFT global
   !

   IF(l_first_pft_parameters) THEN

      !! 1. First time step
      IF(long_print) THEN
         WRITE(numout,*) 'l_first_pft_parameters :we read the parameters from the def files'
      ENDIF
! tzjwb active sinon plante
    !  IF ( active_flags%hydrol_cwrr ) THEN
         
         !! 2.1 Read the flag ok_throughfall_by_pft to know if 
         !!      we have to use the parameter throughfall_by_pft

         !Config Key   = OK_THROUGHFALL_PFT
         !Config Desc  = Activate use of PERCENT_THROUGHFALL_PFT
         !Config If    = HYDROL_CWRR
         !Config Def   = FALSE
         !Config Help  = If NOT OFF_LINE_MODE it is always TRUE (coupled with a GCM)
         !Config Units = [FLAG]
    !     IF ( .NOT. OFF_LINE_MODE ) ok_throughfall_by_pft = .TRUE.
         ok_throughfall_by_pft = .TRUE.
         CALL getin_p('OK_THROUGHFALL_PFT',ok_throughfall_by_pft)   

    !  END IF
   
      !! 2.2 Memory allocation for the pfts-parameters
      CALL pft_parameters_alloc(active_flags)

      !! 3. Correspondance table 
      
      !! 3.1 Initialisation of the correspondance table
      !! Initialisation of the correspondance table
      IF (nvm == nvmc) THEN
         WRITE(numout,*) 'Message to the user : we will use ORCHIDEE to its standard configuration' 
         pft_to_mtc = (/ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13 /)
      ELSE
         pft_to_mtc(:) = undef_int
      ENDIF !(nvm  == nvmc)
      
      !! 3.2 Reading of the conrrespondance table in the .def file
      !
      !Config Key   = PFT_TO_MTC
      !Config Desc  = correspondance array linking a PFT to MTC
      !Config if    = OK_SECHIBA or OK_STOMATE
      !Config Def   = 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('PFT_TO_MTC',pft_to_mtc)
      
      !! 3.3 If the user want to use the standard configuration, he needn't to fill the correspondance array
      !!     If the configuration is wrong, send a error message to the user.
      IF(nvm /= nvmc ) THEN
         !
         IF(pft_to_mtc(1) == undef_int) THEN
            CALL ipslerr_p (3,'pft_parameters', &
                 'The array PFT_TO_MTC is empty','','')
         ENDIF !(pft_to_mtc(1) == undef_int)
         !
      ENDIF !(nvm /= nvmc )

      !! 3.4 Some error messages

      !! 3.4.1 What happened if pft_to_mtc(j) > nvmc or pft_to_mtc(j) <=0 (if the mtc doesn't exist)?
       DO j = 1, nvm ! Loop over # PFTs  
          !
          IF( (pft_to_mtc(j) > nvmc) .OR. (pft_to_mtc(j) <= 0) ) THEN
             WRITE(numout,*) 'pft_to_mtc(j),j,nvmc: ',pft_to_mtc(j),j,nvmc,nvm
             CALL ipslerr_p (3,'pft_parameters', &
                  'the metaclass chosen does not exist','','')
          ENDIF !( (pft_to_mtc(j) > nvmc) .OR. (pft_to_mtc(j) <= 0) )
          !
       ENDDO  ! Loop over # PFTs  


       !! 3.4.2 Check if pft_to_mtc(1) = 1 
       IF(pft_to_mtc(1) /= 1) THEN
          !
          CALL ipslerr_p (3,'pft_parameters', &
               'the first pft has to be the bare soil','','')
          !
       ELSE
          !
          DO j = 2,nvm ! Loop over # PFTs different from bare soil
             !
             IF(pft_to_mtc(j) == 1) THEN
                 CALL ipslerr_p (3,'pft_parameters', &
                      'only pft_to_mtc(1) has to be the bare soil','','')
             ENDIF ! (pft_to_mtc(j) == 1)
             !
          ENDDO ! Loop over # PFTs different from bare soil
          !
       ENDIF !(pft_to_mtc(1) /= 1)
      

      !! 4.Initialisation of the pfts-parameters
      CALL pft_parameters_init(active_flags)

      !! 5. Useful data

      !! 5.1 Read the name of the PFTs given by the user
      !
      !Config Key   = PFT_NAME
      !Config Desc  = Name of a PFT
      !Config if    = OK_SECHIBA or OK_STOMATE
      !Config Def   = bare ground, tropical broad-leaved evergreen, tropical broad-leaved raingreen, 
      !Config         temperate needleleaf evergreen, temperate broad-leaved evergreen temperate broad-leaved summergreen,
      !Config         boreal needleleaf evergreen, boreal broad-leaved summergreen, boreal needleleaf summergreen,
      !Config         C3 grass, C4 grass, C3 agriculture, C4 agriculture    
      !Config Help  = the user can name the new PFTs he/she introducing for new species
      !Config Units = [-]
      CALL getin_p('PFT_NAME',pft_name)

      !! 5.2 A useful message to the user: correspondance between the number of the pft
      !! and the name of the associated mtc 
      DO j = 1,nvm ! Loop over # PFTs
         !
         WRITE(numout,*) 'the PFT',j, 'called  ', PFT_name(j),'corresponds to the MTC : ',MTC_name(pft_to_mtc(j))
         !
      ENDDO ! Loop over # PFTs


      !! 6. End message
      IF(long_print) THEN
         WRITE(numout,*) 'pft_parameters_done'
      ENDIF

      !! 8. Reset flag
      l_first_pft_parameters = .FALSE.

   ELSE 

      RETURN

   ENDIF !(l_first_pft_parameters)

 END SUBROUTINE pft_parameters_main
 !
 !=
 !

!! ================================================================================================================================
!! SUBROUTINE   : pft_parameters_init 
!!
!>\BRIEF          This subroutine initializes all the pft parameters by the default values
!! of the corresponding metaclasse. 
!!
!! DESCRIPTION  : This subroutine is called after the reading of the number of PFTS and the correspondence
!!                table defined by the user in the configuration files. \n
!!                With the correspondence table, the subroutine can search the default values for the parameter
!!                even if the PFTs are classified in a random order (except bare soil). \n
!!                With the correspondence table, the subroutine can initialize the pft parameters in function
!!                of the flags activated (ok_sechiba, ok_stomate, ok_co2, routing, new_hydrol...).\n
!!
!! RECENT CHANGE(S): Didier Solyga : Simplified PFT loops : use vector notation. 
!!
!! MAIN OUTPUT VARIABLE(S): None
!!
!! REFERENCE(S) : None
!!
!! FLOWCHART    : None
!! \n
!_ ================================================================================================================================

 SUBROUTINE pft_parameters_init(active_flags)
  
   IMPLICIT NONE
   
   !! 0. Variables and parameters declaration

   !! 0.1 Input variables
   
   TYPE(control_type),INTENT(in) :: active_flags  !! What parts of the code are activated ? (true/false)

   !! 0.4 Local variables

   INTEGER(i_std)                :: jv            !! Index (unitless) 
!_ ================================================================================================================================ 

   !
   ! 1. Correspondance between the PFTs values and thes MTCs values 
   !
 

   ! 1.1 For parameters used anytime
   
   PFT_name(:) = MTC_name(pft_to_mtc(:))
   !
   ! Vegetation structure 
   !
   veget_ori_fixed_test_1(:) = veget_ori_fixed_mtc(pft_to_mtc(:))
   llaimax(:) = llaimax_mtc(pft_to_mtc(:))
   llaimin(:) = llaimin_mtc(pft_to_mtc(:))
   height_presc(:) = height_presc_mtc(pft_to_mtc(:))
   type_of_lai(:) = type_of_lai_mtc(pft_to_mtc(:))
   natural(:) = natural_mtc(pft_to_mtc(:))
   !
   ! Water - sechiba
   !
   If (active_flags%hydrol_cwrr ) THEN
      humcste(:) = humcste_cwrr(pft_to_mtc(:)) ! values for 2m soil depth
   ELSE
      humcste(:) = humcste_mtc(pft_to_mtc(:))  ! values for 4m soil depth 
   END IF
   !
   ! Soil - vegetation
   !
   pref_soil_veg(:) = pref_soil_veg_mtc(pft_to_mtc(:))
   !
   ! Vegetation - age classes
   !
   agec_group(:) = agec_group_mtc(pft_to_mtc(:))
   !
   ! Photosynthesis
   !
   is_c4(:) = is_c4_mtc(pft_to_mtc(:))
   vcmax_fix(:) = vcmax_fix_mtc(pft_to_mtc(:))
   downregulation_co2_coeff(:) = downregulation_co2_coeff_mtc(pft_to_mtc(:))
   E_KmC(:)      = E_KmC_mtc(pft_to_mtc(:))
   E_KmO(:)      = E_KmO_mtc(pft_to_mtc(:))
   E_gamma_star(:) = E_gamma_star_mtc(pft_to_mtc(:))
   E_Vcmax(:)    = E_Vcmax_mtc(pft_to_mtc(:))
   E_Jmax(:)     = E_Jmax_mtc(pft_to_mtc(:))
   aSV(:)        = aSV_mtc(pft_to_mtc(:))
   bSV(:)        = bSV_mtc(pft_to_mtc(:))
   tphoto_min(:) = tphoto_min_mtc(pft_to_mtc(:))
   tphoto_max(:) = tphoto_max_mtc(pft_to_mtc(:))
   aSJ(:)        = aSJ_mtc(pft_to_mtc(:))
   bSJ(:)        = bSJ_mtc(pft_to_mtc(:))
   D_Vcmax(:)     = D_Vcmax_mtc(pft_to_mtc(:))
   D_Jmax(:)     = D_Jmax_mtc(pft_to_mtc(:))
   E_Rd(:)       = E_Rd_mtc(pft_to_mtc(:))
   Vcmax25(:)    = Vcmax25_mtc(pft_to_mtc(:))
   arJV(:)       = arJV_mtc(pft_to_mtc(:))
   brJV(:)       = brJV_mtc(pft_to_mtc(:))
   KmC25(:)      = KmC25_mtc(pft_to_mtc(:))
   KmO25(:)      = KmO25_mtc(pft_to_mtc(:))
   gamma_star25(:)  = gamma_star25_mtc(pft_to_mtc(:))
   a1(:)         = a1_mtc(pft_to_mtc(:))
   b1(:)         = b1_mtc(pft_to_mtc(:))
   g0(:)         = g0_mtc(pft_to_mtc(:))
   h_protons(:)  = h_protons_mtc(pft_to_mtc(:))
   fpsir(:)      = fpsir_mtc(pft_to_mtc(:))
   fQ(:)         = fQ_mtc(pft_to_mtc(:))     
   fpseudo(:)    = fpseudo_mtc(pft_to_mtc(:))    
   kp(:)         = kp_mtc(pft_to_mtc(:))
   alpha(:)      = alpha_mtc(pft_to_mtc(:))
   gbs(:)        = gbs_mtc(pft_to_mtc(:))
   theta(:)      = theta_mtc(pft_to_mtc(:))        
   alpha_LL(:)   = alpha_LL_mtc(pft_to_mtc(:))
   ext_coeff(:) = ext_coeff_mtc(pft_to_mtc(:))
   !
   !! Define labels from physiologic characteristics 
   !
   leaf_tab(:) = leaf_tab_mtc(pft_to_mtc(:)) 
   pheno_model(:) = pheno_model_mtc(pft_to_mtc(:))   
   !
   is_tree(:) = .FALSE.
   DO jv = 1,nvm
      IF ( leaf_tab(jv) <= 2 ) is_tree(jv) = .TRUE.
   END DO
      !
   is_deciduous(:) = .FALSE.
   DO jv = 1,nvm
      IF ( is_tree(jv) .AND. (pheno_model(jv) /= "none") ) is_deciduous(jv) = .TRUE.
   END DO
   !
   is_evergreen(:) = .FALSE.
   DO jv = 1,nvm
      IF ( is_tree(jv) .AND. (pheno_model(jv) == "none") ) is_evergreen(jv) = .TRUE.
   END DO
   !
   is_needleleaf(:) = .FALSE.
   DO jv = 1,nvm
      IF ( leaf_tab(jv) == 2 ) is_needleleaf(jv) = .TRUE.
   END DO
   !
   is_tropical(:) = is_tropical_mtc(pft_to_mtc(:))
   is_temperate(:) = is_temperate_mtc(pft_to_mtc(:))
   is_boreal(:) = is_boreal_mtc(pft_to_mtc(:))

   ! 1.2 For sechiba parameters

   IF (active_flags%ok_sechiba) THEN
      !
      ! Vegetation structure - sechiba
      !
      rveg_pft(:) = rveg_mtc(pft_to_mtc(:))
      !
      ! Evapotranspiration -  sechiba
      !
      rstruct_const(:) = rstruct_const_mtc(pft_to_mtc(:))
      kzero(:) = kzero_mtc(pft_to_mtc(:))
      !
      ! Water - sechiba
      !
      wmax_veg(:) = wmax_veg_mtc(pft_to_mtc(:))
      IF ( .NOT.(active_flags%hydrol_cwrr) .OR.  (active_flags%hydrol_cwrr .AND. ok_throughfall_by_pft) ) THEN
         throughfall_by_pft(:) = throughfall_by_mtc(pft_to_mtc(:))
      ENDIF
      !
      ! Albedo - sechiba
      !
      snowa_aged(:) = snowa_aged_mtc(pft_to_mtc(:))
      snowa_dec(:) = snowa_dec_mtc(pft_to_mtc(:)) 
      alb_leaf_vis(:) = alb_leaf_vis_mtc(pft_to_mtc(:))  
      alb_leaf_nir(:) = alb_leaf_nir_mtc(pft_to_mtc(:))
      leaf_ssa(:,ivis) = leaf_ssa_vis_mtc(pft_to_mtc(:))
      leaf_ssa(:,inir) = leaf_ssa_nir_mtc(pft_to_mtc(:))
      leaf_psd(:,ivis) = leaf_psd_vis_mtc(pft_to_mtc(:))
      leaf_psd(:,inir) = leaf_psd_nir_mtc(pft_to_mtc(:))
      bgd_reflectance(:,ivis) = bgd_reflectance_vis_mtc(pft_to_mtc(:))
      bgd_reflectance(:,inir) = bgd_reflectance_nir_mtc(pft_to_mtc(:))
      tune_coupled (:) = tune_coupled_mtc(pft_to_mtc(:))  
      leaf_to_shoot_clumping(:) = leaf_to_shoot_clumping_mtc(pft_to_mtc(:))
      lai_correction_factor(:) = lai_correction_factor_mtc(pft_to_mtc(:))
      min_level_sep(:) = min_level_sep_mtc(pft_to_mtc(:))
      !
      ! Diffuco and hydrol_arch
      !
      lai_top(:) = lai_top_mtc(pft_to_mtc(:))

   ENDIF !(active_flags%ok_sechiba)

   ! 1.3 For BVOC parameters
   
   IF (active_flags%ok_inca) THEN
      !
      ! Biogenic Volatile Organic Compounds
      !
      em_factor_isoprene(:) = em_factor_isoprene_mtc(pft_to_mtc(:))
      em_factor_monoterpene(:) = em_factor_monoterpene_mtc(pft_to_mtc(:))
      em_factor_ORVOC(:) = em_factor_ORVOC_mtc(pft_to_mtc(:)) 
      em_factor_OVOC(:) = em_factor_OVOC_mtc(pft_to_mtc(:))
      em_factor_MBO(:) = em_factor_MBO_mtc(pft_to_mtc(:))
      em_factor_methanol(:) = em_factor_methanol_mtc(pft_to_mtc(:))
      em_factor_acetone(:) = em_factor_acetone_mtc(pft_to_mtc(:)) 
      em_factor_acetal(:) = em_factor_acetal_mtc(pft_to_mtc(:))
      em_factor_formal(:) = em_factor_formal_mtc(pft_to_mtc(:))
      em_factor_acetic(:) = em_factor_acetic_mtc(pft_to_mtc(:))
      em_factor_formic(:) = em_factor_formic_mtc(pft_to_mtc(:))
      em_factor_no_wet(:) = em_factor_no_wet_mtc(pft_to_mtc(:))
      em_factor_no_dry(:) = em_factor_no_dry_mtc(pft_to_mtc(:))
      Larch(:) = Larch_mtc(pft_to_mtc(:)) 
      !-
   ENDIF !(active_flags%ok_inca)

   ! 1.4 For stomate parameters

   IF (active_flags%ok_stomate) THEN
      !
      ! Vegetation structure - stomate
      !
      sla(:) = sla_mtc(pft_to_mtc(:))
      lai_happy(:) = lai_happy_mtc(pft_to_mtc(:))
      !
      ! Allocation - stomate
      !
      S0(:) = S0_mtc(pft_to_mtc(:)) 
      !
      ! Respiration - stomate
      !
      maint_resp_slope_c(:) = maint_resp_slope_c_mtc(pft_to_mtc(:))               
      maint_resp_slope_b(:) = maint_resp_slope_b_mtc(pft_to_mtc(:))
      maint_resp_slope_a(:) = maint_resp_slope_a_mtc(pft_to_mtc(:))
      cm_zero_leaf(:) = cm_zero_leaf_mtc(pft_to_mtc(:))
      cm_zero_sapabove(:) = cm_zero_sapabove_mtc(pft_to_mtc(:))
      cm_zero_sapbelow(:) = cm_zero_sapbelow_mtc(pft_to_mtc(:)) 
      cm_zero_heartabove(:) = cm_zero_heartabove_mtc(pft_to_mtc(:)) 
      cm_zero_heartbelow(:) = cm_zero_heartbelow_mtc(pft_to_mtc(:))
      cm_zero_root(:) = cm_zero_root_mtc(pft_to_mtc(:))
      cm_zero_fruit(:) = cm_zero_fruit_mtc(pft_to_mtc(:))   
      coeff_maint_init(:) = coeff_maint_init_mtc(pft_to_mtc(:))
      IF (active_flags%ok_functional_allocation) THEN 
         ! Respiration (functional allocation stomate)
         frac_growthresp(:) = frac_growthresp_fun_all_mtc(pft_to_mtc(:)) 
         cm_zero_carbres(:) = cm_zero_carbres_fun_all_mtc(pft_to_mtc(:))
         cm_zero_labile(:) = cm_zero_labile_fun_all_mtc(pft_to_mtc(:))   
      ELSE
         ! Respiration (resource limitation stomate) 
         frac_growthresp(:) = frac_growthresp_res_lim_mtc(pft_to_mtc(:))
         cm_zero_carbres(:) = cm_zero_carbres_res_lim_mtc(pft_to_mtc(:))
         cm_zero_labile(:) = cm_zero_labile_res_lim_mtc(pft_to_mtc(:))
      ENDIF
      gpp_to_labile(:) = gpp_to_labile_mtc(pft_to_mtc(:))

      !
      ! Stand structure
      !
      pipe_density(:) = pipe_density_mtc(pft_to_mtc(:))
      pipe_tune1(:) = pipe_tune1_mtc(pft_to_mtc(:)) 
      pipe_tune2(:) = pipe_tune2_mtc(pft_to_mtc(:))  
      pipe_tune3(:) = pipe_tune3_mtc(pft_to_mtc(:)) 
      pipe_tune4(:) = pipe_tune4_mtc(pft_to_mtc(:))
      tree_ff(:) = tree_ff_mtc(pft_to_mtc(:))
      pipe_k1(:) = pipe_k1_mtc(pft_to_mtc(:)) 
      pipe_tune_exp_coeff(:) = pipe_tune_exp_coeff_mtc(pft_to_mtc(:))
      mass_ratio_heart_sap(:) = mass_ratio_heart_sap_mtc(pft_to_mtc(:))
      lai_to_height(:) = lai_to_height_mtc(pft_to_mtc(:)) 
      canopy_cover = canopy_cover_mtc(pft_to_mtc(:))
      nmaxtrees(:) = nmaxtrees_mtc(pft_to_mtc(:))
      height_init_min(:) = height_init_min_mtc(pft_to_mtc(:))
      height_init_max(:) = height_init_max_mtc(pft_to_mtc(:))
      alpha_self_thinning(:) = alpha_self_thinning_mtc(pft_to_mtc(:))
      beta_self_thinning(:) = beta_self_thinning_mtc(pft_to_mtc(:))
      fuelwood_diameter(:) = fuelwood_diameter_mtc(pft_to_mtc(:))
      coppice_kill_be_wood(:) = coppice_kill_be_wood_mtc(pft_to_mtc(:))

      !
      ! Growth - stomate
      !
      cn_leaf_prescribed(:) = cn_leaf_prescribed_mtc(pft_to_mtc(:))
      fcn_wood(:) = fcn_wood_mtc(pft_to_mtc(:))
      fcn_root(:) = fcn_root_mtc(pft_to_mtc(:))
      k_latosa_max(:) = k_latosa_max_mtc(pft_to_mtc(:))
      k_latosa_min(:) = k_latosa_min_mtc(pft_to_mtc(:))
      fruit_alloc(:) = fruit_alloc_mtc(pft_to_mtc(:))
      m_dv(:) = m_dv_mtc(pft_to_mtc(:))
      lai_max_to_happy(:) = lai_max_to_happy_mtc(pft_to_mtc(:))

      !
      ! Hydraulic architecture - sechiba?
      !
      k_root(:) = k_root_mtc(pft_to_mtc(:))
      k_sap(:) = k_sap_mtc(pft_to_mtc(:))
      k_leaf(:) = k_leaf_mtc(pft_to_mtc(:))
      phi_leaf(:) = phi_leaf_mtc(pft_to_mtc(:))
      phi_50(:) = phi_50_mtc(pft_to_mtc(:))
      c_cavitation(:) = c_cavitation_mtc(pft_to_mtc(:))
      phi_soil_tune(:) = phi_soil_tune_mtc(pft_to_mtc(:))

      !---------------------------------------------------------------------------------------
      ! Hydraulic architecture - tzjh
      
      gpsi(:)=gpsi_mtc(pft_to_mtc(:))
      gpsi_50(:)=gpsi_50_mtc(pft_to_mtc(:))
      gmax(:)=gmax_mtc(pft_to_mtc(:))
      gmin(:)=gmin_mtc(pft_to_mtc(:))

      kmax_leaf(:)=kmax_leaf_mtc(pft_to_mtc(:))
      kmax_stem(:)=kmax_stem_mtc(pft_to_mtc(:))
      kmax_root(:)=kmax_root_mtc(pft_to_mtc(:))
      a_leaf(:)=a_leaf_mtc(pft_to_mtc(:))
      a_stem(:)=a_stem_mtc(pft_to_mtc(:))
      a_root(:)=a_root_mtc(pft_to_mtc(:)) 
      P50_leaf(:)=P50_leaf_mtc(pft_to_mtc(:))
      P50_stem(:)=P50_stem_mtc(pft_to_mtc(:))
      P50_root(:)=P50_root_mtc(pft_to_mtc(:))
      
      wood_density(:)=wood_density_mtc(pft_to_mtc(:))
      w_density_stem(:)=w_density_stem_mtc(pft_to_mtc(:))
      root_shoot_ratio(:)=root_shoot_ratio_mtc(pft_to_mtc(:))
      rwc_root(:)=rwc_root_mtc(pft_to_mtc(:))
      root_density(:)=root_density_mtc(pft_to_mtc(:))
      LDMC(:)=LDMC_mtc(pft_to_mtc(:))
      sla_hydro(:)=sla_hydro_mtc(pft_to_mtc(:))

      cxyl(:)=cxyl_mtc(pft_to_mtc(:))
      cr(:)=cr_mtc(pft_to_mtc(:))
      cl(:)=cl_mtc(pft_to_mtc(:))
      !---------------------------------------------------------------------------------------

      !
      ! Mortality - stomate_kill
      !
      death_distribution_factor(:) = death_distribution_factor_mtc(pft_to_mtc(:))
      npp_reset_value(:) = npp_reset_value_mtc(pft_to_mtc(:))
      
      !
      ! Fire - stomate
      !
      flam(:) = flam_mtc(pft_to_mtc(:))
      resist(:) = resist_mtc(pft_to_mtc(:))
      !
      ! Flux - LUC
      !
      coeff_lcchange_s(:) = coeff_lcchange_s_mtc(pft_to_mtc(:))
      coeff_lcchange_m(:) = coeff_lcchange_m_mtc(pft_to_mtc(:))
      coeff_lcchange_l(:) = coeff_lcchange_l_mtc(pft_to_mtc(:))
      !
      ! Phenology
      !
      !
      ! 1. Stomate
      !
      lai_max(:) = lai_max_mtc(pft_to_mtc(:))
      pheno_type(:) = pheno_type_mtc(pft_to_mtc(:))
      !
      ! 2. Leaf Onset
      !
      pheno_gdd_crit_c(:) = pheno_gdd_crit_c_mtc(pft_to_mtc(:))
      pheno_gdd_crit_b(:) = pheno_gdd_crit_b_mtc(pft_to_mtc(:))         
      pheno_gdd_crit_a(:) = pheno_gdd_crit_a_mtc(pft_to_mtc(:))
      ngd_crit(:) =  ngd_crit_mtc(pft_to_mtc(:))
      opti_kpheno_crit(:) = opti_kpheno_crit_mtc(pft_to_mtc(:))
      ncdgdd_temp(:) = ncdgdd_temp_mtc(pft_to_mtc(:)) 
      hum_frac(:) = hum_frac_mtc(pft_to_mtc(:))
      hum_min_time(:) = hum_min_time_mtc(pft_to_mtc(:))
      tau_sap(:) = tau_sap_mtc(pft_to_mtc(:))
      tau_fruit(:) = tau_fruit_mtc(pft_to_mtc(:))
      tau_root(:) = tau_root_mtc(pft_to_mtc(:))
      tau_leaf(:) = tau_leaf_mtc(pft_to_mtc(:))
      ecureuil(:) = ecureuil_mtc(pft_to_mtc(:))
      alloc_min(:) = alloc_min_mtc(pft_to_mtc(:))
      alloc_max(:) = alloc_max_mtc(pft_to_mtc(:))
      demi_alloc(:) = demi_alloc_mtc(pft_to_mtc(:))
      !
      ! 3. Senescence
      !
      leaffall(:) = leaffall_mtc(pft_to_mtc(:))
      senescence_type(:) = senescence_type_mtc(pft_to_mtc(:)) 
      senescence_hum(:) = senescence_hum_mtc(pft_to_mtc(:)) 
      nosenescence_hum(:) = nosenescence_hum_mtc(pft_to_mtc(:)) 
      max_turnover_time(:) = max_turnover_time_mtc(pft_to_mtc(:))
      min_turnover_time(:) = min_turnover_time_mtc(pft_to_mtc(:))
      min_leaf_age_for_senescence(:) = min_leaf_age_for_senescence_mtc(pft_to_mtc(:))
      senescence_temp_c(:) = senescence_temp_c_mtc(pft_to_mtc(:))
      senescence_temp_b(:) = senescence_temp_b_mtc(pft_to_mtc(:))
      senescence_temp_a(:) = senescence_temp_a_mtc(pft_to_mtc(:))
      gdd_senescence(:) = gdd_senescence_mtc(pft_to_mtc(:))
      !
      ! DGVM
      !
      residence_time(:) = residence_time_mtc(pft_to_mtc(:))
      tmin_crit(:) = tmin_crit_mtc(pft_to_mtc(:))
      tcm_crit(:) = tcm_crit_mtc(pft_to_mtc(:))
      mortality_min(:) = mortality_min_mtc(pft_to_mtc(:))
      mortality_max(:) = mortality_max_mtc(pft_to_mtc(:))
      ref_mortality(:) = ref_mortality_mtc(pft_to_mtc(:))

      ! added by yitong yao in 07 Jan 2020 08:17

      plc_kill_frac(:)=plc_kill_frac_mtc(pft_to_mtc(:))
      ! added by yitong yao in 07 Jan 2020 08:17 
      
      ! added by yitong yao in 09 Feb 2020 22:56
      mor_kill_frac(:) = mor_kill_frac_mtc(pft_to_mtc(:))
      ! added by yitong yao in 09 Feb 2020 22:56 above line 

      ! Season average
      !
      ! Only an effect on the roots has been implemented for the
      ! GPP-based waterstress. We use tau_sap rather than tau_roots
      ! because we only want to implement the long term change in
      ! allocation owing to height-induced drought stress. Short
      ! term adaptation to drought is not accounted for (except
      ! for stomatal closure).
      tau_hum_growingseason(:) = tau_sap_mtc(pft_to_mtc(:))
      DO jv = 2,nvm
         IF(.NOT. is_tree(jv)) THEN
            ! Grasses have no sapwood so use a constant instead of tau_sap
            tau_hum_growingseason(jv) = tau_hum_growingseason_grass
         ENDIF
      END DO

      ! Originally, dens_target was just used in the FM routines.
      ! Now, however, it is used for all forests.
      dens_target(:) = dens_target_mtc(pft_to_mtc(:))

      !
      ! FOREST MANAGEMENT
      !
      IF (active_flags%forest_management &
           .OR. active_flags%ok_functional_allocation) THEN
!!$         plantation(:) = plantation_mtc(pft_to_mtc(:))
!!$         fm_allo_a(:) = fm_allo_a_mtc(pft_to_mtc(:))
!!$         fm_allo_c(:) = fm_allo_c_mtc(pft_to_mtc(:))
!!$         fm_allo_d(:) = fm_allo_d_mtc(pft_to_mtc(:))
!!$         fm_allo_p(:) = fm_allo_p_mtc(pft_to_mtc(:))
!!$         fm_allo_q(:) = fm_allo_q_mtc(pft_to_mtc(:))
!!$         allo_crown_a0(:) = allo_crown_a0_mtc(pft_to_mtc(:))
!!$         allo_crown_a1(:) = allo_crown_a1_mtc(pft_to_mtc(:))
!!$         allo_crown_a2(:) = allo_crown_a2_mtc(pft_to_mtc(:))
!!$         decl_factor(:) = decl_factor_mtc(pft_to_mtc(:))
!!$         opt_factor(:) = opt_factor_mtc(pft_to_mtc(:))
         h_first(:) = h_first_mtc(pft_to_mtc(:))
         largest_tree_dia(:) = largest_tree_dia_mtc(pft_to_mtc(:))
         thinstrat(:) = thinstrat_mtc(pft_to_mtc(:))
         taumin(:) = taumin_mtc(pft_to_mtc(:))
         taumax(:) = taumax_mtc(pft_to_mtc(:))
         alpha_rdi_upper(:) =  alpha_rdi_upper_mtc(pft_to_mtc(:))
         beta_rdi_upper(:) =  beta_rdi_upper_mtc(pft_to_mtc(:))
         alpha_rdi_lower(:) =  alpha_rdi_lower_mtc(pft_to_mtc(:))
         beta_rdi_lower(:) =  beta_rdi_lower_mtc(pft_to_mtc(:))  
         branch_ratio(:) = branch_ratio_mtc(pft_to_mtc(:))
         branch_harvest(:) = branch_harvest_mtc(pft_to_mtc(:))
         coppice_diameter(:) = coppice_diameter_mtc(pft_to_mtc(:))
         shoots_per_stool(:) = shoots_per_stool_mtc(pft_to_mtc(:))
         src_rot_length(:) = src_rot_length_mtc(pft_to_mtc(:))
         src_nrots(:) = src_nrots_mtc(pft_to_mtc(:))
         deleuze_a(:) = deleuze_a_mtc(pft_to_mtc(:))
         deleuze_b(:) = deleuze_b_mtc(pft_to_mtc(:))
         deleuze_p_all(:) = deleuze_p_all_mtc(pft_to_mtc(:))
         deleuze_p_coppice(:) = deleuze_p_coppice_mtc(pft_to_mtc(:))
         recruitment_light_threshold(:) = recruitment_light_threshold_mtc(pft_to_mtc(:))
         dia_recr(:) = dia_recr_mtc(pft_to_mtc(:))
         hei_recr(:) = hei_recr_mtc(pft_to_mtc(:)) 
      END IF

      !
      ! CROPLAND MANAGEMENT
      !
      harvest_ratio(:) = harvest_ratio_mtc(pft_to_mtc(:))
      
   ENDIF !(active_flags%ok_stomate)



 END SUBROUTINE pft_parameters_init
 !
 !
 !

!! ================================================================================================================================
!! SUBROUTINE   : pft_parameters_alloc
!!
!>\BRIEF         This subroutine allocates memory needed for the PFT parameters 
!! in function  of the flags activated.  
!!
!! DESCRIPTION  : None
!!
!! RECENT CHANGE(S): None
!!
!! MAIN OUTPUT VARIABLE(S): None
!!
!! REFERENCE(S) : None
!!
!! FLOWCHART    : None
!! \n
!_ ================================================================================================================================

 SUBROUTINE pft_parameters_alloc(active_flags)

   IMPLICIT NONE

   !! 0. Variables and parameters declaration

   !! 0.1 Input variables 
   
   TYPE(control_type),INTENT(in) :: active_flags  !! What parts of the code are activated ? (true/false)

   !! 0.4 Local variables
   
   LOGICAL :: l_error                             !! Diagnostic boolean for error allocation (true/false) 
   INTEGER :: ier                                 !! Return value for memory allocation (0-N, unitless)
!_ ================================================================================================================================


   !
   ! 1. Parameters used anytime
   !

   l_error = .FALSE.

   ALLOCATE(pft_to_mtc(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for pft_to_mtc. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(PFT_name(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for PFT_name. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(height_presc(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for height_presc. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(is_tree(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for is_tree. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(natural(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for natural. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(is_c4(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for is_c4. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(humcste(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for humcste. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(downregulation_co2_coeff(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for downregulation_co2_coeff. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(E_KmC(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for E_KmC. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(E_KmO(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for E_KmO. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(E_gamma_star(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for E_gamma_star. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(E_vcmax(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for E_Vcmax. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(E_Jmax(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for E_Jmax. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(aSV(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for aSV. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(bSV(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for bSV. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(tphoto_min(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for tphoto_min. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(tphoto_max(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for tphoto_max. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(aSJ(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for aSJ. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(bSJ(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for bSJ. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(D_Vcmax(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for D_Vcmax. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(D_Jmax(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for D_Jmax. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(E_Rd(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for E_Rd. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(Vcmax25(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for Vcmax25. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(arJV(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for arJV. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(brJV(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for brJV. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(KmC25(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for KmC25. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(KmO25(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for KmO25. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(gamma_star25(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for gamma_star25. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(a1(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for a1. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(b1(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for b1. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(g0(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for g0. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(h_protons(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for h_protons. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(fpsir(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for fpsir. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(fQ(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for fQ. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(fpseudo(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for fpseudo. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(kp(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for kp. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(alpha(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for alpha. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(gbs(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for gbs. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(theta(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for theta. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(alpha_LL(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for alpha_LL. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(ext_coeff(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for ext_coeff. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(veget_ori_fixed_test_1(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for veget_ori_fixed_test_1. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(llaimax(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for llaimax. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(llaimin(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for llaimin. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(type_of_lai(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for type_of_lai. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(vcmax_fix(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for vcmax_fix. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(pref_soil_veg(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for pref_soil_veg. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(agec_group(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for agec_group. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(start_index(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for start_index. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(nagec_pft(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for nagec_pft. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(leaf_tab(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for leaf_tab. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(pheno_model(nvm),stat=ier)
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for pheno_model. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF
      
   ALLOCATE(is_deciduous(nvm),stat=ier) 
   l_error = l_error .OR. (ier /= 0) 
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for is_deciduous. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(is_temperate(nvm),stat=ier) 
   l_error = l_error .OR. (ier /= 0) 
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for is_temperate. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(is_boreal(nvm),stat=ier) 
   l_error = l_error .OR. (ier /= 0) 
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for is_boreal. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(is_evergreen(nvm),stat=ier) 
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for is_evergreen. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(is_needleleaf(nvm),stat=ier)  
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for is_needleleaf. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF

   ALLOCATE(is_tropical(nvm),stat=ier)   
   l_error = l_error .OR. (ier /= 0)
   IF (l_error) THEN
      WRITE(numout,*) ' Memory allocation error for is_tropical. We stop. We need nvm words = ',nvm
      CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
   END IF


   !
   ! 2. Parameters used if ok_sechiba only
   !
   IF ( active_flags%ok_sechiba ) THEN

      l_error = .FALSE.

      ALLOCATE(rstruct_const(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for rstruct_const. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(kzero(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for kzero. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(rveg_pft(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for rveg_pft. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(wmax_veg(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for wmax_veg. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      IF ( .NOT.(active_flags%hydrol_cwrr) .OR. (active_flags%hydrol_cwrr .AND. ok_throughfall_by_pft) ) THEN
         ALLOCATE(throughfall_by_pft(nvm),stat=ier)
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for throughfall_by_pft. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF
      END IF

      ALLOCATE(snowa_aged(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for snowa_aged. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(snowa_dec(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for snowa_dec. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(alb_leaf_vis(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for alb_leaf_vis. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(alb_leaf_nir(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for alb_leaf_nir. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(leaf_ssa(nvm,n_spectralbands),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for leaf_ssa. We stop. We need nvm*n_spectralbands words = ',&
              nvm*n_spectralbands
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(leaf_psd(nvm,n_spectralbands),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for leaf_psd. We stop. We need nvm*n_spectralbands words = ',&
              nvm*n_spectralbands
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(bgd_reflectance(nvm,n_spectralbands),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for bgd_reflectance. We need nvm*n_spectralbands words = ',&
              nvm*n_spectralbands
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(leaf_to_shoot_clumping(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for leaf_to_shoot_clumping. We need nvm words = ',&
              nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF


      ALLOCATE(tune_coupled(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for tune_coupled. We need nvm words = ',&
              nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF


      ALLOCATE(lai_correction_factor(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for lai_correction_factor. We need nvm words = ',&
              nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(min_level_sep(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for min_level_sep. We need nvm words = ',&
              nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(lai_top(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for lai_top. We need nvm words = ',&
              nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF


      IF( active_flags%ok_inca ) THEN
         
         l_error = .FALSE.
         
         ALLOCATE(em_factor_isoprene(nvm),stat=ier)
         l_error = l_error .OR. (ier /= 0) 
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for em_factor_isoprene. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(em_factor_monoterpene(nvm),stat=ier)
         l_error = l_error .OR. (ier /= 0) 
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for em_factor_monoterpene. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(em_factor_ORVOC(nvm),stat=ier)
         l_error = l_error .OR. (ier /= 0) 
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for em_factor_ORVOC. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(em_factor_OVOC(nvm),stat=ier)
         l_error = l_error .OR. (ier /= 0)       
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for em_factor_OVOC. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(em_factor_MBO(nvm),stat=ier)
         l_error = l_error .OR. (ier /= 0) 
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for em_factor_MBO. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(em_factor_methanol(nvm),stat=ier)
         l_error = l_error .OR. (ier /= 0) 
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for em_factor_methanol. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(em_factor_acetone(nvm),stat=ier)
         l_error = l_error .OR. (ier /= 0) 
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for em_factor_acetone. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(em_factor_acetal(nvm),stat=ier)
         l_error = l_error .OR. (ier /= 0) 
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for em_factor_acetal. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(em_factor_formal(nvm),stat=ier)
         l_error = l_error .OR. (ier /= 0) 
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for em_factor_formal. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(em_factor_acetic(nvm),stat=ier)
         l_error = l_error .OR. (ier /= 0)       
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for em_factor_acetic. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(em_factor_formic(nvm),stat=ier)
         l_error = l_error .OR. (ier /= 0) 
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for em_factor_formic. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(em_factor_no_wet(nvm),stat=ier)
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for em_factor_no_wet. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(em_factor_no_dry(nvm),stat=ier)
         l_error = l_error .OR. (ier /= 0)       
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for em_factor_no_dry. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(Larch(nvm),stat=ier)
         l_error = l_error .OR. (ier /= 0) 
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for Larch. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

      ENDIF ! (active_flags%ok_inca) 

   ENDIF !(active_flags%ok_sechiba)

   !
   ! 3. Parameters used if ok_stomate only
   !
   IF ( active_flags%ok_stomate ) THEN

      l_error = .FALSE.
      
      !
      ! PHOTOSYNTHESIS
      !
      ALLOCATE(sla(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for sla. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

!!$      ALLOCATE(tphoto_min_a(nvm),stat=ier)
!!$      l_error = l_error .OR. (ier /= 0)
!!$      IF (l_error) THEN
!!$         WRITE(numout,*) ' Memory allocation error for tphoto_min_a. We stop. We need nvm words = ',nvm
!!$         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
!!$      END IF
!!$
!!$      ALLOCATE(tphoto_min_b(nvm),stat=ier)
!!$      l_error = l_error .OR. (ier /= 0)
!!$      IF (l_error) THEN
!!$         WRITE(numout,*) ' Memory allocation error for tphoto_min_b. We stop. We need nvm words = ',nvm
!!$         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
!!$      END IF
!!$
!!$      ALLOCATE(tphoto_min_c(nvm),stat=ier)
!!$      l_error = l_error .OR. (ier /= 0)
!!$      IF (l_error) THEN
!!$         WRITE(numout,*) ' Memory allocation error for tphoto_min_c. We stop. We need nvm words = ',nvm
!!$         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
!!$      END IF
!!$
!!$      ALLOCATE(tphoto_opt_a(nvm),stat=ier)
!!$      l_error = l_error .OR. (ier /= 0)
!!$      IF (l_error) THEN
!!$         WRITE(numout,*) ' Memory allocation error for tphoto_opt_a. We stop. We need nvm words = ',nvm
!!$         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
!!$      END IF
!!$
!!$      ALLOCATE(tphoto_opt_b(nvm),stat=ier)
!!$      l_error = l_error .OR. (ier /= 0)
!!$      IF (l_error) THEN
!!$         WRITE(numout,*) ' Memory allocation error for tphoto_opt_b. We stop. We need nvm words = ',nvm
!!$         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
!!$      END IF
!!$
!!$      ALLOCATE(tphoto_opt_c(nvm),stat=ier)
!!$      l_error = l_error .OR. (ier /= 0)
!!$      IF (l_error) THEN
!!$         WRITE(numout,*) ' Memory allocation error for tphoto_opt_c. We stop. We need nvm words = ',nvm
!!$         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
!!$      END IF
!!$
!!$      ALLOCATE(tphoto_max_a(nvm),stat=ier)
!!$      l_error = l_error .OR. (ier /= 0)
!!$      IF (l_error) THEN
!!$         WRITE(numout,*) ' Memory allocation error for tphoto_max_a. We stop. We need nvm words = ',nvm
!!$         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
!!$      END IF
!!$
!!$      ALLOCATE(tphoto_max_b(nvm),stat=ier)
!!$      l_error = l_error .OR. (ier /= 0)
!!$      IF (l_error) THEN
!!$         WRITE(numout,*) ' Memory allocation error for tphoto_max_b. We stop. We need nvm words = ',nvm
!!$         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
!!$      END IF
!!$
!!$      ALLOCATE(tphoto_max_c(nvm),stat=ier)
!!$      l_error = l_error .OR. (ier /= 0)
!!$      IF (l_error) THEN
!!$         WRITE(numout,*) ' Memory allocation error for tphoto_max_c. We stop. We need nvm words = ',nvm
!!$         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
!!$      END IF
 

      !
      ! RESPIRATION
      !
      ALLOCATE(S0(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for S0. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(L0(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for L0. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(maint_resp_slope(nvm,3),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for maint_resp_slope. We stop. We need nvm*3 words = ',nvm*3
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
      maint_resp_slope(:,:) = zero

      ALLOCATE(maint_resp_slope_c(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for maint_resp_slope_c. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(maint_resp_slope_b(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for maint_resp_slope_b. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(maint_resp_slope_a(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for maint_resp_slope_a. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(coeff_maint_zero(nvm,nparts),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for coeff_maint_zero. We stop. We need nvm*nparts words = ',nvm*nparts
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
      coeff_maint_zero(:,:) = zero

      ALLOCATE(cm_zero_leaf(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for cm_zero_leaf. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(cm_zero_sapabove(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for cm_zero_sapabove. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(cm_zero_sapbelow(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for cm_zero_sapbelow. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(cm_zero_heartabove(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for cm_zero_heartabove. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(cm_zero_heartbelow(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for cm_zero_heartbelow. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(cm_zero_root(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for cm_zero_root. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(cm_zero_fruit(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for cm_zero_fruit. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(cm_zero_carbres(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for cm_zero_carbres. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
      
      ALLOCATE(cm_zero_labile(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for cm_zero_labile. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
      
      ALLOCATE(coeff_maint_init(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for coeff_maint_init. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
      
      ALLOCATE(frac_growthresp(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for frac_growthresp. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(gpp_to_labile(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for gpp_to_labile. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      !
      ! STAND STRUCTURE
      !

      ALLOCATE(pipe_density(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for pipe_density. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
      
      ALLOCATE(pipe_tune1(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for pipe_tune1. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(pipe_tune2(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for pipe_tune2. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(pipe_tune3(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for pipe_tune3. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(pipe_tune4(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for pipe_tune4. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(tree_ff(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for tree_ff. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(pipe_k1(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for pipe_k1. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(pipe_tune_exp_coeff(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for pipe_tune_exp_coeff. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(mass_ratio_heart_sap(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for mass_ratio_heart_sap. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(lai_to_height(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for lai_to_height. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(canopy_cover(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for canopy_cover. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(nmaxtrees(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for nmaxtrees. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(height_init_min(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for height_init_min. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
      
      ALLOCATE(height_init_max(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for height_init_max. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
      
      ALLOCATE(alpha_self_thinning(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for alpha_self_thinning. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
      
      ALLOCATE(beta_self_thinning(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for beta_self_thinning. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
         
      ALLOCATE(fuelwood_diameter(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for fuelwood_diameter. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
         
      ALLOCATE(coppice_kill_be_wood(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for coppice_kill_be_wood. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      !
      ! GROWTH
      !
      ALLOCATE(cn_leaf_prescribed(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for cn_leaf_prescribed. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(fcn_wood(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for fcn_wood. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(fcn_root(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for fcn_root. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(k_latosa_max(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for k_latosa_max. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(k_latosa_min(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for k_latosa_min. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(fruit_alloc(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for fruit_alloc. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(m_dv(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for m_dv. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
      
      ALLOCATE(recruitment_light_threshold(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for recruitment_light_threshold. We stop. We need nvm words = ',nvm
         STOP 'pft_parameters_alloc'
      END IF
      
      ALLOCATE(dia_recr(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for dia_recr. We stop. We need nvm words = ',nvm
         STOP 'pft_parameters_alloc'
      END IF
      
      ALLOCATE(hei_recr(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for hei_recr. We stop. We need nvm words = ',nvm
         STOP 'pft_parameters_alloc'
      END IF

      ALLOCATE(lai_max_to_happy(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for lai_max_to_happy. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(k_root(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for k_root. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(k_sap(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for k_sap. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(k_leaf(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for k_leaf. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(phi_leaf(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for phi_leaf. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(phi_50(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for phi_50. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(c_cavitation(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for c_cavitation. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(phi_soil_tune(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for phi_soil_tune. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(lai_happy(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for lai_happy. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

 
    !---------------------------------------------------------------------------------------
    ! tzjh hydraulic architecture
 
      ALLOCATE(gpsi(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for gpsi. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(gpsi_50(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for gpsi_50. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(gmax(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for gmax. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(gmin(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for gmin. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(kmax_leaf(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for kmax_leaf. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(kmax_stem(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for kmax_stem. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(kmax_root(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for kmax_root. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(a_leaf(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for a_leaf. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(a_stem(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for a_stem. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(a_root(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for a_root. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(P50_leaf(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for P50_leaf. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(P50_stem(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for P50_stem. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(P50_root(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for P50_root. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(wood_density(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for wood_density. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(w_density_stem(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for w_density_stem. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(root_shoot_ratio(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for root_shoot_ration. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
      
      ALLOCATE(rwc_root(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for rwc_root. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
      
      ALLOCATE(root_density(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for root_density. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(LDMC(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for LDMC. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(sla_hydro(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for sla_hydro. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(cxyl(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for cxyl. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(cr(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for cr. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(cl(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for cl. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      !
      ! PRESCRIBE
      !

      ALLOCATE(tune_reserves_in_sapling(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for tune_reserves_in_sapling. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
      ! This prevents a crash in getin_p with NAG, though I'm not sure why.
      tune_reserves_in_sapling(:)=zero


      !
      ! MORTALITY
      !

      ALLOCATE(death_distribution_factor(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for death_distribution_factor. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(npp_reset_value(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for npp_reset_value. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      !
      ! FIRE
      !
      ALLOCATE(flam(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for . We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(resist(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for resist. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      !
      ! LUC
      !
      ALLOCATE(coeff_lcchange_s(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for coeff_lcchange_s. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(coeff_lcchange_m(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for coeff_lcchange_m. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(coeff_lcchange_l(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for coeff_lcchange_l. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      !
      ! PHENOLOGY
      !
      ! 1. stomate
      !
      ALLOCATE(lai_max(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for lai_max. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(pheno_type(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for pheno_type. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
     
      !
      ! 2. Leaf Onset
      !
      ALLOCATE(pheno_gdd_crit_c(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for pheno_gdd_crit_c. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(pheno_gdd_crit_b(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for pheno_gdd_crit_b. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(pheno_gdd_crit_a(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for pheno_gdd_crit_a. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(pheno_gdd_crit(nvm,3),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for pheno_gdd_crit. We stop. We need nvm words = ',nvm*3
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
      pheno_gdd_crit(:,:) = zero

      ALLOCATE(ngd_crit(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for ngd_crit. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(opti_kpheno_crit(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for opti_kpheno_crit. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(ncdgdd_temp(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for ncdgdd_temp. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(hum_frac(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for hum_frac. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(hum_min_time(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for hum_min_time. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
   
      ALLOCATE(tau_sap(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for tau_sap. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(tau_fruit(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for tau_fruit. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(tau_root(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for tau_root. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(tau_leaf(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for tau_leaf. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(ecureuil(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for ecureuil. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(alloc_min(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for alloc_min. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(alloc_max(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for alloc_max. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(demi_alloc(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for . We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      !
      ! 3. Senescence
      !
      ALLOCATE(leaffall(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for leaffall. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(senescence_type(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for . We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(senescence_hum(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for senescence_hum. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(nosenescence_hum(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for nosenescence_hum. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(max_turnover_time(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for max_turnover_time. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(min_turnover_time(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for min_turnover_time. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(min_leaf_age_for_senescence(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for min_leaf_age_for_senescence. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(senescence_temp_c(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for senescence_temp_c. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(senescence_temp_b(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for senescence_temp_b. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(senescence_temp_a(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for senescence_temp_a. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(senescence_temp(nvm,3),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for senescence_temp. We stop. We need nvm*3 words = ',nvm*3
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
      senescence_temp(:,:) = zero

      ALLOCATE(gdd_senescence(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for gdd_senescence. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(residence_time(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for residence_time. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF
      
      ! added by yitong yao 07 Jan 2020 08:24
       
      ALLOCATE(plc_kill_frac(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for plc_kill_frac. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ! added by yitong yao 07 Jan 2020 08:24      


      ! added by yitong yao 09 Feb 2020 22:58

      ALLOCATE(mor_kill_frac(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for mor_kill_frac. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ! added by yitong yao 09 Feb 2020 22:58


      ALLOCATE(tmin_crit(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for tmin_crit. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(tcm_crit(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for tcm_crit. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(mortality_min(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for mortality_min. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(mortality_max(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for mortality_max. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(ref_mortality(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for ref_mortality. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(tau_hum_growingseason(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for tau_hum_growingseason. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(lai_initmin(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for . We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF


      !
      ! DGVM
      !
   
      !
      ! KILL
      !

      ALLOCATE(dens_target(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for dens_target. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF


      !
      ! BVOC
      !

      
      

    

      
      !
      ! FOREST MANAGEMENT
      !
      IF (active_flags%forest_management .OR. &
           active_flags%ok_functional_allocation) THEN

         ALLOCATE(plantation(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for plantation. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(fm_allo_a(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for fm_allo_a. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF
         ! To prevent a crash in getin_p with NAG.
         fm_allo_a(:)=zero

         ALLOCATE(fm_allo_c(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for fm_allo_c. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF
         ! To prevent a crash in getin_p with NAG.
         fm_allo_c(:)=zero

         ALLOCATE(fm_allo_d(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for fm_allo_d. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF
         ! To prevent a crash in getin_p with NAG.
         fm_allo_d(:)=zero

         ALLOCATE(fm_allo_p(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for fm_allo_p. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF
         ! To prevent a crash in getin_p with NAG.
         fm_allo_p(:)=zero

         ALLOCATE(fm_allo_q(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for fm_allo_q. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF
         ! To prevent a crash in getin_p with NAG.
         fm_allo_q(:)=zero

         ALLOCATE(allo_crown_a0(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for allo_crown_a0. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(allo_crown_a1(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for allo_crown_a1. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(allo_crown_a2(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for allo_crown_a2. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(h_first(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for h_first. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(thinstrat(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for thinstrat. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(taumin(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for taumin. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(taumax(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for taumax. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(alpha_rdi_upper(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for alpha_rdi_upper. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(beta_rdi_upper(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for beta_rdi_upper. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(alpha_rdi_lower(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for alpha_rdi_lower. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(beta_rdi_lower(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for beta_rdi_lower. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(largest_tree_dia(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for largest_tree_dia. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(branch_ratio(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for branch_ratio. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(branch_harvest(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for branch_harvest. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(decl_factor(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for decl_factor. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

        ! ALLOCATE(opt_factor(nvm),stat=ier)   
        ! l_error = l_error .OR. (ier /= 0)
        ! IF (l_error) THEN
        !    WRITE(numout,*) ' Memory allocation error for opt_factor. We stop. We need nvm words = ',nvm
        !    CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
        ! END IF

         ALLOCATE(coppice_diameter(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for coppice_diameter. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(shoots_per_stool(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for shoots_per_stool. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(src_rot_length(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for src_rot_length. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(src_nrots(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for src_nrots. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(deleuze_a(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for deleuze_a. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(deleuze_b(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for deleuze_b. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(deleuze_p_all(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for deleuze_p_all. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF

         ALLOCATE(deleuze_p_coppice(nvm),stat=ier)   
         l_error = l_error .OR. (ier /= 0)
         IF (l_error) THEN
            WRITE(numout,*) ' Memory allocation error for deleuze_p_coppice. We stop. We need nvm words = ',nvm
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         END IF
      END IF



      !
      ! CROPLAND MANAGEMENT
      !
      ALLOCATE(harvest_ratio(nvm),stat=ier)   
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for harvest_ratio. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      !
      ! OTHER
      !
      ALLOCATE(bm_sapl_old(nvm,nparts,nelements),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for bm_sapl_old. We stop. We need nvm*nparts*nelements words = ',& 
              &  nvm*nparts*nelements
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(migrate(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for migrate. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(maxdia(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for maxdia. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(cn_sapl(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for cn_sapl. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

      ALLOCATE(leaf_timecst(nvm),stat=ier)
      l_error = l_error .OR. (ier /= 0)
      IF (l_error) THEN
         WRITE(numout,*) ' Memory allocation error for leaf_timecst. We stop. We need nvm words = ',nvm
         CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
      END IF

   ENDIF ! (active_flags%ok_stomate)

 END SUBROUTINE pft_parameters_alloc
!
!=
!

!! ================================================================================================================================
!! SUBROUTINE   : config_pft_parameters 
!!
!>\BRIEF          This subroutine will read the imposed values for the global pft
!! parameters (sechiba + stomate). It is not called if IMPOSE_PARAM is set to NO.
!!
!! DESCRIPTION  : None
!!
!! RECENT CHANGE(S): None
!!
!! MAIN OUTPUT VARIABLE(S): None
!!
!! REFERENCE(S) : None
!!
!! FLOWCHART    : None
!! \n
!_ ================================================================================================================================

 SUBROUTINE config_pft_parameters
   
   IMPLICIT NONE

   !! 0. Variables and parameters declaration
  
   !! 0.4 Local variable

   LOGICAL, SAVE  :: first_call = .TRUE.  !! To keep first call trace (true/false)
!$OMP THREADPRIVATE(first_call)
   INTEGER(i_std) :: jv,ivm               !! Index (untiless)

!_ ================================================================================================================================ 

   IF (first_call) THEN

      !
      ! Vegetation structure
      !

      !Config Key   = LEAF_TAB
      !Config Desc  = leaf type : 1=broad leaved tree, 2=needle leaved tree, 3=grass 4=bare ground
      !Config if    = OK_STOMATE
      !Config Def   = 4, 1, 1, 2, 1, 1, 2, 1, 2, 3, 3, 3, 3 
      !Config Help  = 
      !Config Units = [-] 
      CALL getin_p('LEAF_TAB',leaf_tab)
      
      !Config Key   = PHENO_MODEL
      !Config Desc  = which phenology model is used? (tabulated) 
      !Config if    = OK_STOMATE
      !Config Def   = none, none, moi, none, none, ncdgdd, none, ncdgdd, ngd, moigdd, moigdd, moigdd, moigdd
      !Config Help  =
      !Config Units = [-] 
      CALL getin_p('PHENO_MODEL',pheno_model)
      
      !! Redefine the values for is_tree, is_deciduous, is_needleleaf, is_evergreen if values have been modified
      !! in run.def

      is_tree(:) = .FALSE.
      DO jv = 1,nvm
         IF ( leaf_tab(jv) <= 2 ) is_tree(jv) = .TRUE.
      END DO
      !
      is_deciduous(:) = .FALSE.
      DO jv = 1,nvm
         IF ( is_tree(jv) .AND. (pheno_model(jv) /= "none") ) is_deciduous(jv) = .TRUE.
      END DO
      !
      is_evergreen(:) = .FALSE.
      DO jv = 1,nvm
         IF ( is_tree(jv) .AND. (pheno_model(jv) == "none") ) is_evergreen(jv) = .TRUE.
      END DO
      !
      is_needleleaf(:) = .FALSE.
      DO jv = 1,nvm
         IF ( leaf_tab(jv) == 2 ) is_needleleaf(jv) = .TRUE.
      END DO


      !Config Key   = SECHIBA_LAI
      !Config Desc  = laimax for maximum lai(see also type of lai interpolation)
      !Config if    = OK_SECHIBA or IMPOSE_VEG
      !Config Def   = 0., 8., 8., 4., 4.5, 4.5, 4., 4.5, 4., 2., 2., 2., 2.
      !Config Help  = Maximum values of lai used for interpolation of the lai map
      !Config Units = [m^2/m^2]
      CALL getin_p('SECHIBA_LAI',llaimax)

      !Config Key   = LLAIMIN
      !Config Desc  = laimin for minimum lai(see also type of lai interpolation)
      !Config if    = OK_SECHIBA or IMPOSE_VEG
      !Config Def   = 0., 8., 0., 4., 4.5, 0., 4., 0., 0., 0., 0., 0., 0.
      !Config Help  = Minimum values of lai used for interpolation of the lai map
      !Config Units = [m^2/m^2]
      CALL getin_p('LLAIMIN',llaimin)

      !Config Key   = SLOWPROC_HEIGHT
      !Config Desc  = prescribed height of vegetation 
      !Config if    = OK_SECHIBA
      !Config Def   = 0., 30., 30., 20., 20., 20., 15., 15., 15., .5, .6, 1., 1.
      !Config Help  =
      !Config Units = [m] 
      CALL getin_p('SLOWPROC_HEIGHT',height_presc)

      !Config Key   = TYPE_OF_LAI
      !Config Desc  = Type of behaviour of the LAI evolution algorithm 
      !Config if    = OK_SECHIBA
      !Config Def   = inter, inter, inter, inter, inter, inter, inter, inter, inter, inter, inter, inter, inter
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('TYPE_OF_LAI',type_of_lai)

      !Config Key   = NATURAL
      !Config Desc  = natural? 
      !Config if    = OK_SECHIBA, OK_STOMATE
      !Config Def   = y, y, y, y, y, y, y, y, y, y, y, n, n 
      !Config Help  =
      !Config Units = [BOOLEAN]
      CALL getin_p('NATURAL',natural)

      
      !
      ! Photosynthesis
      !

      !Config Key   = IS_C4
      !Config Desc  = flag for C4 vegetation types
      !Config if    = OK_SECHIBA or OK_STOMATE
      !Config Def   = n, n, n, n, n, n, n, n, n, n, n, y, n, y
      !Config Help  =
      !Config Units = [BOOLEAN]
      CALL getin_p('IS_C4',is_c4)

      !Config Key   = VCMAX_FIX
      !Config Desc  = values used for vcmax when STOMATE is not activated
      !Config if    = OK_SECHIBA and NOT(OK_STOMATE)
      !Config Def   = 0., 40., 50., 30., 35., 40.,30., 40., 35., 60., 60., 70., 70.
      !Config Help  =
      !Config Units = [micromol/m^2/s] 
      CALL getin_p('VCMAX_FIX',vcmax_fix)

      !Config Key   = E_KmC
      !Config Desc  = Energy of activation for KmC
      !Config if    = OK_CO2
      !Config Def   = undef,  79430., 79430., 79430., 79430., 79430., 79430., 79430., 79430., 79430., 79430., 79430., 79430.
      !Config Help  = See Medlyn et al. (2002) 
      !Config Units = [J mol-1]
      CALL getin_p('E_KMC',E_KmC)

      !Config Key   = E_KmO
      !Config Desc  = Energy of activation for KmO
      !Config if    = OK_CO2
      !Config Def   = undef, 36380.,  36380.,  36380.,  36380.,  36380., 36380., 36380., 36380., 36380., 36380., 36380., 36380.
      !Config Help  = See Medlyn et al. (2002) 
      !Config Units = [J mol-1]
      CALL getin_p('E_KMO',E_KmO)

      !Config Key   = E_gamma_star
      !Config Desc  = Energy of activation for gamma_star
      !Config if    = OK_CO2
      !Config Def   = undef, 37830.,  37830.,  37830.,  37830.,  37830., 37830., 37830., 37830., 37830., 37830., 37830., 37830.
      !Config Help  = See Medlyn et al. (2002) from Bernacchi al. (2001) 
      !Config Units = [J mol-1]
      CALL getin_p('E_GAMMA_STAR',E_gamma_star)

      !Config Key   = E_Vcmax
      !Config Desc  = Energy of activation for Vcmax
      !Config if    = OK_CO2
      !Config Def   = undef, 71513., 71513., 71513., 71513., 71513., 71513., 71513., 71513., 71513., 67300., 71513., 67300.
      !Config Help  = See Table 2 of Yin et al. (2009) for C4 plants and Kattge & Knorr (2007) for C3 plants (table 3)
      !Config Units = [J mol-1]
      CALL getin_p('E_VCMAX',E_Vcmax)

      !Config Key   = E_Jmax
      !Config Desc  = Energy of activation for Jmax
      !Config if    = OK_CO2
      !Config Def   = undef, 49884., 49884., 49884., 49884., 49884., 49884., 49884., 49884., 49884., 77900., 49884., 77900. 
      !Config Help  = See Table 2 of Yin et al. (2009) for C4 plants and Kattge & Knorr (2007) for C3 plants (table 3)
      !Config Units = [J mol-1]
      CALL getin_p('E_JMAX',E_Jmax)

      !Config Key   = aSV
      !Config Desc  = a coefficient of the linear regression (a+bT) defining the Entropy term for Vcmax
      !Config if    = OK_CO2
      !Config Def   = undef, 668.39, 668.39, 668.39, 668.39, 668.39, 668.39, 668.39, 668.39, 668.39, 641.64, 668.39, 641.64 
      !Config Help  = See Table 3 of Kattge & Knorr (2007) - For C4 plants, we assume that there is no acclimation and that at for a temperature of 25°C, aSV is the same for both C4 and C3 plants (no strong jusitification - need further parametrization)
      !Config Units = [J K-1 mol-1]
      CALL getin_p('ASV',aSV)

      !Config Key   = bSV
      !Config Desc  = b coefficient of the linear regression (a+bT) defining the Entropy term for Vcmax
      !Config if    = OK_CO2
      !Config Def   = undef, -1.07, -1.07, -1.07, -1.07, -1.07, -1.07, -1.07, -1.07, -1.07, 0., -1.07, 0. 
      !Config Help  = See Table 3 of Kattge & Knorr (2007) - For C4 plants, we assume that there is no acclimation
      !Config Units = [J K-1 mol-1 °C-1]
      CALL getin_p('BSV',bSV)

      !Config Key   = TPHOTO_MIN
      !Config Desc  = minimum photosynthesis temperature (deg C)
      !Config if    = OK_STOMATE
      !Config Def   = undef,  -4., -4., -4., -4.,-4.,-4., -4., -4., -4., -4., -4., -4.
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('TPHOTO_MIN',tphoto_min)

      !Config Key   = TPHOTO_MAX
      !Config Desc  = maximum photosynthesis temperature (deg C)
      !Config if    = OK_STOMATE
      !Config Def   = undef, 55., 55., 55., 55., 55., 55., 55., 55., 55., 55., 55., 55.
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('TPHOTO_MAX',tphoto_max)

      !Config Key   = aSJ
      !Config Desc  = a coefficient of the linear regression (a+bT) defining the Entropy term for Jmax
      !Config if    = OK_CO2
      !Config Def   = undef, 659.70, 659.70, 659.70, 659.70, 659.70, 659.70, 659.70, 659.70, 659.70, 630., 659.70, 630. 
      !Config Help  = See Table 3 of Kattge & Knorr (2007) - and Table 2 of Yin et al. (2009) for C4 plants
      !Config Units = [J K-1 mol-1]
      CALL getin_p('ASJ',aSJ)

      !Config Key   = bSJ
      !Config Desc  = b coefficient of the linear regression (a+bT) defining the Entropy term for Jmax
      !Config if    = OK_CO2
      !Config Def   = undef, -0.75, -0.75, -0.75, -0.75, -0.75, -0.75, -0.75, -0.75, -0.75, 0., -0.75, 0. 
      !Config Help  = See Table 3 of Kattge & Knorr (2007) - For C4 plants, we assume that there is no acclimation
      !Config Units = [J K-1 mol-1 °C-1]
      CALL getin_p('BSJ',bSJ)

      !Config Key   = D_Vcmax
      !Config Desc  = Energy of deactivation for Vcmax
      !Config if    = OK_CO2
      !Config Def   = undef, 200000., 200000., 200000., 200000., 200000., 200000., 200000., 200000., 200000., 192000., 200000., 192000.
      !Config Help  = Medlyn et al. (2002) also uses 200000. for C3 plants (same value than D_Jmax). 'Consequently', we use the value of D_Jmax for C4 plants.
      !Config Units = [J mol-1]
      CALL getin_p('D_VCMAX',D_Vcmax)

      !Config Key   = D_Jmax
      !Config Desc  = Energy of deactivation for Jmax
      !Config if    = OK_CO2
      !Config Def   = undef, 200000., 200000., 200000., 200000., 200000., 200000., 200000., 200000., 200000., 192000., 200000., 192000.
      !Config Help  = See Table 2 of Yin et al. (2009)
      !Config Units = [J mol-1]
      CALL getin_p('D_JMAX',D_Jmax)

      !Config Key   = E_Rd
      !Config Desc  = Energy of activation for Rd
      !Config if    = OK_CO2
      !Config Def   = undef, 46390., 46390., 46390., 46390., 46390., 46390., 46390., 46390., 46390., 46390., 46390., 46390.
      !Config Help  = See Table 2 of Yin et al. (2009)
      !Config Units = [J mol-1]
      CALL getin_p('E_RD',E_Rd)

      !Config Key   = VCMAX25
      !Config Desc  = Maximum rate of Rubisco activity-limited carboxylation at 25°C
      !Config if    = OK_STOMATE
      !Config Def   = undef, 65., 65., 35., 45., 55., 35., 45., 35., 70., 70., 70., 70.
      !Config Help  =
      !Config Units = [micromol/m^2/s]
      CALL getin_p('VCMAX25',Vcmax25)

      !Config Key   = ARJV
      !Config Desc  = a coefficient of the linear regression (a+bT) defining the Jmax25/Vcmax25 ratio 
      !Config if    = OK_STOMATE
      !Config Def   = undef, 2.59, 2.59, 2.59, 2.59, 2.59, 2.59, 2.59, 2.59, 2.59, 1.715, 2.59, 1.715
      !Config Help  = See Table 3 of Kattge & Knorr (2007) - For C4 plants, we assume that there is no acclimation and that for a temperature of 25°C, aSV is the same for both C4 and C3 plants (no strong jusitification - need further parametrization)
      !Config Units = [mu mol e- (mu mol CO2)-1]
      CALL getin_p('ARJV',arJV)

      !Config Key   = BRJV
      !Config Desc  = b coefficient of the linear regression (a+bT) defining the Jmax25/Vcmax25 ratio 
      !Config if    = OK_STOMATE
      !Config Def   = undef, -0.035, -0.035, -0.035, -0.035, -0.035, -0.035, -0.035, -0.035, -0.035, 0., -0.035, 0.
      !Config Help  = See Table 3 of Kattge & Knorr (2007) -  We assume No acclimation term for C4 plants
      !Config Units = [(mu mol e- (mu mol CO2)-1) (°C)-1]
      CALL getin_p('BRJV',brJV)

      !Config Key   = KmC25
      !Config Desc  = Michaelis–Menten constant of Rubisco for CO2 at 25°C
      !Config if    = OK_CO2
      !Config Def   = undef, 404.9, 404.9, 404.9, 404.9, 404.9, 404.9, 404.9, 404.9, 404.9, 650., 404.9, 650.
      !Config Help  = See Table 2 of Yin et al. (2009) for C4 plants and Medlyn et al. (2002) for C3 plants
      !Config Units = [ubar]
      CALL getin_p('KMC25',KmC25)

      !Config Key   = KmO25
      !Config Desc  = Michaelis–Menten constant of Rubisco for O2 at 25°C
      !Config if    = OK_CO2
      !Config Def   = undef, 278400., 278400., 278400., 278400., 278400., 278400., 278400., 278400., 278400., 450000., 278400., 450000.
      !Config Help  = See Table 2 of Yin et al. (2009) for C4 plants and Medlyn et al. (2002) for C3 plants
      !Config Units = [ubar]
      CALL getin_p('KMO25',KmO25)

      !Config Key   = gamma_star25
      !Config Desc  = Ci-based CO2 compensation point in the absence of Rd at 25°C (ubar)
      !Config if    = OK_CO2
      !Config Def   = undef, 42.75, 42.75, 42.75, 42.75, 42.75, 42.75, 42.75, 42.75, 42.75, 42.75, 42.75, 42.75
      !Config Help  = See Medlyn et al. (2002) for C3 plants - For C4 plants, we use the same value (probably uncorrect)
      !Config Units = [ubar]
      CALL getin_p('gamma_star25',gamma_star25)

      !Config Key   = a1
      !Config Desc  = Empirical factor involved in the calculation of fvpd
      !Config if    = OK_CO2
      !Config Def   = undef, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85
      !Config Help  = See Table 2 of Yin et al. (2009)
      !Config Units = [-]
      CALL getin_p('A1',a1)

      !Config Key   = b1
      !Config Desc  = Empirical factor involved in the calculation of fvpd
      !Config if    = OK_CO2
      !Config Def   = undef, 0.14, 0.14, 0.14, 0.14, 0.14, 0.14, 0.14, 0.14, 0.14, 0.20, 0.14, 0.20
      !Config Help  = See Table 2 of Yin et al. (2009)
      !Config Units = [-]
      CALL getin_p('B1',b1)

      !Config Key   = g0
      !Config Desc  = Residual stomatal conductance when irradiance approaches zero 
      !Config if    = OK_CO2
      !Config Def   = undef, 0.00625, 0.00625, 0.00625, 0.00625, 0.00625, 0.00625, 0.00625, 0.00625, 0.00625, 0.01875, 0.00625, 0.01875 
      !Config Help  = Value from ORCHIDEE - No other reference.
      !Config Units = [mol m−2 s−1 bar−1]
      CALL getin_p('G0',g0)

      !Config Key   = h_protons
      !Config Desc  = Number of protons required to produce one ATP
      !Config if    = OK_CO2
      !Config Def   = undef, 4., 4., 4., 4., 4., 4., 4., 4., 4., 4., 4., 4. 
      !Config Help  = See Table 2 of Yin et al. (2009) - h parameter
      !Config Units = [mol mol-1]
      CALL getin_p('H_PROTONS',h_protons)

      !Config Key   = fpsir
      !Config Desc  = Fraction of PSII e− transport rate partitioned to the C4 cycle
      !Config if    = OK_CO2
      !Config Def   = undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, 0.4, undef, 0.4 
      !Config Help  = See Table 2 of Yin et al. (2009)
      !Config Units = [-]
      CALL getin_p('FPSIR',fpsir)

      !Config Key   = fQ
      !Config Desc  = Fraction of electrons at reduced plastoquinone that follow the Q-cycle
      !Config if    = OK_CO2
      !Config Def   = undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, 1., undef, 1.
      !Config Help  = See Table 2 of Yin et al. (2009) - Values for C3 plants are not used
      !Config Units = [-]
      CALL getin_p('FQ',fQ)

      !Config Key   = fpseudo
      !Config Desc  = Fraction of electrons at PSI that follow pseudocyclic transport 
      !Config if    = OK_CO2
      !Config Def   = undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, 0.1, undef, 0.1
      !Config Help  = See Table 2 of Yin et al. (2009) - Values for C3 plants are not used
      !Config Units = [-]
      CALL getin_p('FPSEUDO',fpseudo)

      !Config Key   = kp
      !Config Desc  = Initial carboxylation efficiency of the PEP carboxylase
      !Config if    = OK_CO2
      !Config Def   = undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, 0.7, undef, 0.7
      !Config Help  = See Table 2 of Yin et al. (2009) 
      !Config Units = [mol m−2 s−1 bar−1]
      CALL getin_p('KP',kp)

      !Config Key   = alpha
      !Config Desc  = Fraction of PSII activity in the bundle sheath
      !Config if    = OK_CO2
      !Config Def   = undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, 0.1, undef, 0.1
      !Config Help  = See legend of Figure 6 of Yin et al. (2009)
      !Config Units = [-]
      CALL getin_p('ALPHA',alpha)

      !Config Key   = gbs
      !Config Desc  = Bundle-sheath conductance
      !Config if    = OK_CO2
      !Config Def   = undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, 0.003, undef, 0.003
      !Config Help  = See legend of Figure 6 of Yin et al. (2009)
      !Config Units = [mol m−2 s−1 bar−1]
      CALL getin_p('GBS',gbs)

      !Config Key   = theta
      !Config Desc  = Convexity factor for response of J to irradiance
      !Config if    = OK_CO2
      !Config Def   = undef, 0.7, 0.7, 0.7, 0.7, 0.7, 0.7, 0.7, 0.7, 0.7, 0.7, 0.7, 0.7
      !Config Help  = See Table 2 of Yin et al. (2009)   
      !Config Units = [−]
      CALL getin_p('THETA',theta)

      !Config Key   = alpha_LL
      !Config Desc  = Conversion efficiency of absorbed light into J at strictly limiting light
      !Config if    = OK_CO2
      !Config Def   = undef, 0.3, 0.3, 0.3, 0.3, 0.3, 0.3, 0.3, 0.3, 0.3, 0.3, 0.3, 0.3
      !Config Help  = See comment from Yin et al. (2009) after eq. 4
      !Config Units = [mol e− (mol photon)−1]
      CALL getin_p('ALPHA_LL',alpha_LL)

      !Config Key   = DOWNREGULATION_CO2_COEFF
      !Config Desc  = coefficient for CO2 downregulation (unitless)
      !Config if    = OK_CO2
      !Config Def   = 0., 0.38, 0.38, 0.28, 0.28, 0.28, 0.22, 0.22, 0.22, 0.26, 0.26, 0.26, 0.26
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('DOWNREGULATION_CO2_COEFF',downregulation_co2_coeff)

      !Config Key   = EXT_COEFF
      !Config Desc  = extinction coefficient of the Monsi&Seaki relationship (1953)
      !Config if    = OK_SECHIBA or OK_STOMATE
      !Config Def   = .5, .5, .5, .5, .5, .5, .5, .5, .5, .5, .5, .5, .5
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('EXT_COEFF',ext_coeff)
     
      !
      ! Water-hydrology - sechiba
      !

      !Config Key   = HYDROL_HUMCSTE
      !Config Desc  = Root profile
      !Config Def   = 5., .4, .4, 1., .8, .8, 1., 1., .8, 4., 1., 4., 1. 
      !Config if    = OK_SECHIBA
      !Config Help  = Default values were defined for 4 meters soil depth.
      !Config         For 2 meters soil depth, you may use those ones :
      !Config         5., .8, .8, 1., .8, .8, 1., 1., .8, 4., 4., 4., 4.
      !Config Units = [m]
      CALL getin_p('HYDROL_HUMCSTE',humcste)

      !
      ! Soil - vegetation
      !

      !Config Key   = PREF_SOIL_VEG
      !Config Desc  = The soil tile number for each vegetation
      !Config if    = OK_SECHIBA or OK_STOMATE
      !Config Def   = 1, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3
      !Config Help  = Gives the number of the soil tile on which we will
      !Config         put each vegetation. This allows to divide the hydrological column
      !Config Units = [-]        
      CALL getin_p('PREF_SOIL_VEG',pref_soil_veg)

      !
      ! Vegetation - Age classes
      !
      !Config Key   = NVMAP
      !Config Desc  = The number of PFTs if we ignore age classes.  If nagec = 1, this is just nvm.
      !Config if    = OK_SECHIBA or OK_STOMATE
      !Config Def   = nvm
      !Config Help  = Gives the total number of PFTs ignoring age classes.
      !Config Units = [-]  
      nvmap=nvm
      CALL getin_p('NVMAP',nvmap)
      IF(nagec > 1 .AND. nvmap == nvm)THEN
         WRITE(numout,*) 'WARNING: The number of age classes is greater than one, but'
         WRITE(numout,*) '         the input file indicates that none of the PFTs have age classes.'
         WRITE(numout,*) '         You should change either nagec or nvmap.'
      ENDIF

      !Config Key   = AGEC_GROUP
      !Config Desc  = The group that each PFT belongs to.  
      !Config if    = OK_SECHIBA or OK_STOMATE
      !Config Def   = 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13
      !Config Help  = The group that each PFT belongs to.  If you are not using age classes, this
      !Config         is just equal to the number of the PFT.
      !Config Units = [-]   
      DO ivm=1,nvm
         agec_group(ivm)=ivm
      ENDDO
      CALL getin_p('AGEC_GROUP',agec_group)

      first_call = .FALSE.

   ENDIF !(first_call)

 END SUBROUTINE config_pft_parameters
!
!=
!

!! ================================================================================================================================
!! SUBROUTINE   : config_sechiba_pft_parameters
!!
!>\BRIEF        This subroutine will read the imposed values for the sechiba pft
!! parameters. It is not called if IMPOSE_PARAM is set to NO. 
!!
!! DESCRIPTION  : None
!!
!! RECENT CHANGE(S): None
!!
!! MAIN OUTPUT VARIABLE(S): None
!!
!! REFERENCE(S) : None
!!
!! FLOWCHART    : None
!! \n
!_ ================================================================================================================================

 SUBROUTINE config_sechiba_pft_parameters(active_flags)

   IMPLICIT NONE
  
   !! 0. Variables and parameters declaration

   !! 0.1 Input variables

   TYPE(control_type), INTENT(in) :: active_flags     !! What parts of the code are activated ?

   !! 0.4 Local variable

   LOGICAL, SAVE ::  first_call = .TRUE.   !! To keep first call trace (true/false)
!$OMP THREADPRIVATE(first_call)

!_ ================================================================================================================================ 

   IF (first_call) THEN

      !
      ! Evapotranspiration -  sechiba
      !
      
      !Config Key   = RSTRUCT_CONST
      !Config Desc  = Structural resistance 
      !Config if    = OK_SECHIBA
      !Config Def   = 0.0, 25.0, 25.0, 25.0, 25.0, 25.0, 25.0, 25.0, 25.0,  2.5,  2.0,  2.0,  2.0
      !Config Help  =
      !Config Units = [s/m]
      CALL getin_p('RSTRUCT_CONST',rstruct_const)
      
      !Config Key   = KZERO
      !Config Desc  = A vegetation dependent constant used in the calculation of the surface resistance.
      !Config if    = OK_SECHIBA
      !Config Def   = 0.0, 12.E-5, 12.E-5, 12.e-5, 12.e-5, 25.e-5, 12.e-5,25.e-5, 25.e-5, 30.e-5, 30.e-5, 30.e-5, 30.e-5 
      !Config Help  =
      !Config Units = [kg/m^2/s]
      CALL getin_p('KZERO',kzero)
      
      !Config Key   = RVEG_PFT
      !Config Desc  = Artificial parameter to increase or decrease canopy resistance.
      !Config if    = OK_SECHIBA
      !Config Def   = 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.
      !Config Help  = This parameter is set by PFT.
      !Config Units = [-]
      CALL getin_p('RVEG_PFT',rveg_pft)    
      
      !
      ! Water-hydrology - sechiba
      !

      !Config Key   = WMAX_VEG
      !Config Desc  = Maximum field capacity for each of the vegetations (Temporary): max quantity of water
      !Config if    = OK_SECHIBA
      !Config Def   = 150., 150., 150., 150., 150., 150., 150.,150., 150., 150., 150., 150., 150.
      !Config Help  =
      !Config Units = [kg/m^3]
      CALL getin_p('WMAX_VEG',wmax_veg)
      !
      IF ( .NOT.(active_flags%hydrol_cwrr) .OR. (active_flags%hydrol_cwrr .AND. ok_throughfall_by_pft) ) THEN
         !Config Key   = PERCENT_THROUGHFALL_PFT
         !Config Desc  = Percent by PFT of precip that is not intercepted by the canopy
         !Config if    = OK_SECHIBA OR HYDROL_CWRR
         !Config Def   = 30. 30. 30. 30. 30. 30. 30. 30. 30. 30. 30. 30. 30.
         !Config Help  = During one rainfall event, PERCENT_THROUGHFALL_PFT% of the incident rainfall
         !Config         will get directly to the ground without being intercepted, for each PFT.
         !Config Units = [%]
         CALL getin_p('PERCENT_THROUGHFALL_PFT',throughfall_by_pft)
         throughfall_by_pft(:) = throughfall_by_pft(:) / 100. 
      END IF
      
      !
      ! Albedo - sechiba
      !

      !Config Key   = SNOWA_AGED
      !Config Desc  = Minimum snow albedo value for each vegetation type after aging (dirty old snow)
      !Config if    = OK_SECHIBA
      !Config Def   = 0.35, 0., 0., 0.14, 0.14, 0.14, 0.14, 0.14, 0.14, 0.18, 0.18, 0.18, 0.18
      !Config Help  = Values are from the Thesis of S. Chalita (1992)
      !Config Units = [-]
      CALL getin_p('SNOWA_AGED',snowa_aged)

      !Config Key   = SNOWA_DEC
      !Config Desc  = Decay rate of snow albedo value for each vegetation type as it will be used in condveg_snow
      !Config if    = OK_SECHIBA
      !Config Def   = 0.45, 0.,  0., 0.06, 0.06, 0.11, 0.06, 0.11, 0.11, 0.52,0.52, 0.52, 0.52
      !Config Help  = Values are from the Thesis of S. Chalita (1992)
      !Config Units = [-]
      CALL getin_p('SNOWA_DEC',snowa_dec)

      !Config Key   = ALB_LEAF_VIS
      !Config Desc  = leaf albedo of vegetation type, visible albedo
      !Config if    = OK_SECHIBA
      !Config Def   = .00, .04, .06, .06, .06,.06, .06, .06, .06, .10, .10, .10, .10
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('ALB_LEAF_VIS',alb_leaf_vis)

      !Config Key   = ALB_LEAF_NIR
      !Config Desc  = leaf albedo of vegetation type, near infrared albedo
      !Config if    = OK_SECHIBA
      !Config Def   = .00, .20, .22, .22, .22,.22, .22, .22, .22, .30, .30, .30, .30 
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('ALB_LEAF_NIR',alb_leaf_nir)
      !
      !Config Key  = LEAF_SSA_VIS
      !Config Desc = Leaf_single_scattering_albedo_vis values
      !Config If   = ALBEDO_TYPE == Pinty
      !Config Def  = 0.17192, 0.12560, 0.16230, 0.13838, 0.13202, 0.14720,  
      !              0.14680, 0.14415, 0.15485, 0.17544, 0.17384, 0.17302, 0.17116 
      !Config Help  =
      !Config Units = [-]
      !
      CALL getin_p('LEAF_SSA_VIS',leaf_ssa(:,ivis))
      WRITE(numout,*) 'Single scattering albedo values for the leaves in the VIS spectrum: ',leaf_ssa(:,ivis)
      !
      !Config Key  = LEAF_SSA_NIR
      !Config Desc = Leaf_single_scattering_albedo_nir values
      !Config If   = ALBEDO_TYPE == Pinty
      !Config Def  = 0.70253, 0.68189, 0.69684, 0.68778, 0.68356, 0.69533, &
      !              0.69520, 0.69195, 0.69180, 0.71236, 0.71904, 0.71220, 0.71190
      !Config Help  =
      !Config Units = [-]
      !
      CALL getin_p('LEAF_SSA_NIR',leaf_ssa(:,inir))
      WRITE(numout,*) 'Single scattering albedo values for the leaves in the NIR spectrum: ',leaf_ssa(:,inir)
      !
      !Config Key  = LEAF_PSD_VIS
      !Config Desc = Preferred scattering direction values in the visibile spectra
      !Config If   = ALBEDO_TYPE == Pinty
      !Config Def  = 1.00170, 0.96776, 0.99250, 0.97170, 0.97119, 0.98077, &
      !              0.97672, 0.97810, 0.98605, 1.00490, 1.00360, 1.00320, 1.00130
      !Config Help  =
      !Config Units = [-]
      !
      CALL getin_p('LEAF_PSD_VIS',leaf_psd(:,ivis))
      WRITE(numout,*) 'Preferred scattering direction values for the leaves in the VIS spectrum: ',leaf_psd(:,ivis)
      !
      !Config Key  = LEAF_PSD_NIR
      !Config Desc =  Preferred scattering direction values in the near infrared spectra
      !Config If   = ALBEDO_TYPE == Pinty
      !Config Def  = 2.00520, 1.95120, 1.98990, 1.97020, 1.95900, 1.98190, &
      !              1.98890, 1.97400, 1.97780, 2.02430, 2.03350, 2.02070, 2.02150
      !Config Help  =
      !Config Units = [-]
      !
      CALL getin_p('LEAF_PSD_NIR',leaf_psd(:,inir)) 
      WRITE(numout,*) 'Preferred scattering direction values for the leaves in the NIR spectrum: ',leaf_psd(:,inir)
      !
      !
      !Config Key  = BGRD_REF_VIS
      !Config Desc = Background reflectance values in the visibile spectra
      !Config If   = ALBEDO_TYPE == Pinty
      !Config Def   = 0.2300000,   0.0866667,   0.0800000,   0.0533333,   0.0700000,   0.0933333,   0.0533333,    
      !               0.0833333,   0.0633333,   0.1033330,   0.1566670,   0.1166670,   0.1200000
      !Config Help  =
      !Config Units = [-]
      !
      CALL getin_p('BGRD_REF_VIS',bgd_reflectance(:,ivis)) 
      WRITE(numout,*) 'Background (soil) reflectance values in the VIS spectrum: ',bgd_reflectance(:,ivis)
      !
      !Config Key  = BGRD_REF_NIR
      !Config Desc = Background reflectance values in the near infrared spectra
      !Config If   = ALBEDO_TYPE == Pinty
      !Config Def   = 0.4200000,   0.1500000,   0.1300000,   0.0916667,   0.1066670,   0.1650000,   0.0900000,    
      !               0.1483330,   0.1066670,   0.1900000,   0.3183330,   0.2200000,   0.2183330
      !Config Help  =
      !Config Units = [-]
      !
      CALL getin_p('BGRD_REF_NIR',bgd_reflectance(:,inir)) 
      WRITE(numout,*) 'Background (soil) reflectance values in the NIR spectrum: ',bgd_reflectance(:,inir)

      !
      !Config Key  = LEAF_TO_SHOOT_CLUMPING
      !Config Desc = The leaf-to-shoot clumping factor
      !Config If   = ALBEDO_TYPE == Pinty
      !Config Def   = un,   un,   un,   un,   un,   un,   un,   
      !               un,   un,   un,   un,   un,   un
      !Config Help  =
      !Config Units = [-]
      !
      CALL getin_p('LEAF_TO_SHOOT_CLUMPING',leaf_to_shoot_clumping(:)) 
      WRITE(numout,*) 'Leaf-to-shoot clumping factors: ',leaf_to_shoot_clumping(:)
      !
      !Config Key  = LAI_CORRECTION_FACTOR
      !Config Desc = The correction factor for the LAI for grasslands and crops (see note in pft_parameters)
      !Config If   = ALBEDO_TYPE == Pinty
      !Config Def   = un,   un,   un,   un,   un,   un,   un,   
      !               un,   un,   un,   un,   un,   un
      !Config Help  =
      !Config Units = [-]   
      
      CALL getin_p('TUNE_COUPLED',tune_coupled(:)) 
      WRITE(numout,*) 'Tunning the propotion of LAI contributed to transpiration: ', tune_coupled(:)
      !
      !Config Key  = TUNE_COUPLED
      !Config Desc = The correction factor for the LAI which is coupled with atmosphere
      !Config If   = 
      !Config Def   = un,   un,   un,   un,   un,   un,   un,   
      !               un,   un,   un,   un,   un,   un
      !Config Help  =
      !Config Units = [-]
      
      !
      CALL getin_p('LAI_CORRECTION_FACTOR',lai_correction_factor(:)) 
      WRITE(numout,*) 'LAI correction factors: ',lai_correction_factor(:)

      !Config Key  = MIN_LEVEL_SEP
      !Config Desc = The minimum level thickness we use for photosynthesis 
      !Config If   = ALBEDO_TYPE == Pinty
      !Config Def   = un,   0.1,   0.1,   0.1,   0.1,   0.1,   0.1,   
      !               0.1,   0.1,   0.1,   0.1,   0.1,   0.1
      !Config Help  =
      !Config Units = [m]
      !
      CALL getin_p('MIN_LEVEL_SEP',min_level_sep(:)) 
      WRITE(numout,*) 'Minimum level separation: ',min_level_sep(:)

      !Config Key  = LAI_TOP
      !Config Desc = Definition, in terms of LAI of the top layer 
      !              (used to calculate one of the resistences of 
      !              vbeta3) to calculate transpiration 
      !Config If   = 
      !Config Def  = un,   0.1,   0.1,   0.1,   0.1,   0.1,   0.1,   
      !              0.1,   0.1,   0.1,   0.1,   0.1,   0.1
      !Config Help  =
      !Config Units = [m2 m2]
      !
      CALL getin_p('LAI_TOP',lai_top(:)) 
      WRITE(numout,*) 'Defining the "top layer" for transpiration in terms of LAI: ',lai_top(:)
      
      
      !Config Key  = TUNE_COUPLED
      !Config Desc = Definition, in terms of LAI of the top layer which is contributed to the transpiration 
      !              (used to calculate one of the resistences of vbeta3) to calculate transpiration 
      !Config If   = 
      !Config Def  = un,   un,   un,   un,   un,   un,   un,   
      !              un,   un,   un,   un,   un,   un
      !Config Help  =
      !Config Units = [-]
      !
      CALL getin_p('TUNE_COUPLED',tune_coupled(:)) 
      WRITE(numout,*) 'tunning the "the porpotion of the coupled layer" for transpiration : ',tune_coupled(:)


      IF ( active_flags%ok_inca ) THEN
         !
         ! BVOC
         !

         !Config Key   = ISO_ACTIVITY
         !Config Desc  = Biogenic activity for each age class : isoprene
         !Config if    = DIFFUCO_OK_INCA
         !Config Def   = 0.5, 1.5, 1.5, 0.5
         !Config Help  =
         !Config Units = [-]
         CALL getin_p('ISO_ACTIVITY',iso_activity)

         !Config Key   = METHANOL_ACTIVITY
         !Config Desc  = Isoprene emission factor for each age class : methanol
         !Config if    = DIFFUCO_OK_INCA
         !Config Def   = 1., 1., 0.5, 0.5
         !Config Help  =
         !Config Units = [-]
         CALL getin_p('METHANOL_ACTIVITY',methanol_activity)

         !Config Key   = EM_FACTOR_ISOPRENE
         !Config Desc  = Isoprene emission factor
         !Config if    = DIFFUCO_OK_INCA
         !Config Def   = 0., 24., 24., 8., 16., 45., 8., 8., 8., 16., 24., 5., 5.
         !Config Help  =
         !Config Units = [ugC/g/h] 
         CALL getin_p('EM_FACTOR_ISOPRENE',em_factor_isoprene)

         !Config Key   = EM_FACTOR_MONOTERPENE
         !Config Desc  = Monoterpene emission factor 
         !Config if    = DIFFUCO_OK_INCA 
         !Config Def   = 0., 0.8, 0.8, 2.4, 1.2, 0.8, 2.4, 2.4, 2.4, 0.8, 1.2, 0.2, 0.2
         !Config Help  =
         !Config Units = [ugC/g/h] 
         CALL getin_p('EM_FACTOR_MONOTERPENE',em_factor_monoterpene)

         !Config Key   = EM_FACTOR_ORVOC
         !Config Desc  = ORVOC emissions factor 
         !Config if    = DIFFUCO_OK_INCA 
         !Config Def   = 0., 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5
         !Config Help  =
         !Config Units = [ugC/g/h]  
         CALL getin_p('EM_FACTOR_ORVOC',em_factor_ORVOC)

         !Config Key   = EM_FACTOR_OVOC
         !Config Desc  = OVOC emissions factor
         !Config if    = DIFFUCO_OK_INCA
         !Config Def   = 0., 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5
         !Config Help  =
         !Config Units = [ugC/g/h]        
         CALL getin_p('EM_FACTOR_OVOC',em_factor_OVOC)

         !Config Key   = EM_FACTOR_MBO
         !Config Desc  = MBO emissions factor 
         !Config if    = DIFFUCO_OK_INCA 
         !Config Def   = 0., 0., 0., 20.0, 0., 0., 0., 0., 0., 0., 0., 0., 0.
         !Config Help  =
         !Config Units = [ugC/g/h]  
         CALL getin_p('EM_FACTOR_MBO',em_factor_MBO)

         !Config Key   = EM_FACTOR_METHANOL
         !Config Desc  = Methanol emissions factor 
         !Config if    = DIFFUCO_OK_INCA 
         !Config Def   = 0., 0.6, 0.6, 1.8, 0.9, 0.6, 1.8, 1.8, 1.8, 0.6, 0.9, 2., 2.
         !Config Help  =
         !Config Units = [ugC/g/h]  
         CALL getin_p('EM_FACTOR_METHANOL',em_factor_methanol)

         !Config Key   = EM_FACTOR_ACETONE
         !Config Desc  = Acetone emissions factor
         !Config if    = DIFFUCO_OK_INCA 
         !Config Def   = 0., 0.29, 0.29, 0.87, 0.43, 0.29, 0.87, 0.87, 0.87, 0.29, 0.43, 0.07, 0.07 
         !Config Help  =
         !Config Units = [ugC/g/h]     
         CALL getin_p('EM_FACTOR_ACETONE',em_factor_acetone)

         !Config Key   = EM_FACTOR_ACETAL
         !Config Desc  = Acetaldehyde emissions factor 
         !Config if    = DIFFUCO_OK_INCA
         !Config Def   = 0., 0.1, 0.1, 0.3, 0.15, 0.1, 0.3, 0.3, 0.3, 0.1, 0.15, 0.025, 0.025
         !Config Help  =
         !Config Units = [ugC/g/h]  
         CALL getin_p('EM_FACTOR_ACETAL',em_factor_acetal)

         !Config Key   = EM_FACTOR_FORMAL
         !Config Desc  = Formaldehyde emissions factor
         !Config if    = DIFFUCO_OK_INCA 
         !Config Def   = 0., 0.07, 0.07, 0.2, 0.1, 0.07, 0.2, 0.2, 0.2, 0.07, 0.1, 0.017, 0.017
         !Config Help  = 
         !Config Units = [ugC/g/h]  
         CALL getin_p('EM_FACTOR_FORMAL',em_factor_formal)

         !Config Key   = EM_FACTOR_ACETIC
         !Config Desc  = Acetic Acid emissions factor
         !Config if    = DIFFUCO_OK_INCA 
         !Config Def   = 0., 0.002, 0.002, 0.006, 0.003, 0.002, 0.006, 0.006, 0.006, 0.002, 0.003, 0.0005, 0.0005
         !Config Help  =
         !Config Units = [ugC/g/h]  
         CALL getin_p('EM_FACTOR_ACETIC',em_factor_acetic)

         !Config Key   = EM_FACTOR_FORMIC
         !Config Desc  = Formic Acid emissions factor
         !Config if    = DIFFUCO_OK_INCA
         !Config Def   = 0., 0.01, 0.01, 0.03, 0.015, 0.01, 0.03, 0.03, 0.03, 0.01, 0.015, 0.0025, 0.0025 
         !Config Help  =
         !Config Units = [ugC/g/h]  
         CALL getin_p('EM_FACTOR_FORMIC',em_factor_formic)

         !Config Key   = EM_FACTOR_NO_WET
         !Config Desc  = NOx emissions factor wet soil emissions and exponential dependancy factor 
         !Config if    = DIFFUCO_OK_INCA
         !Config Def   = 0., 2.6, 0.06, 0.03, 0.03, 0.03, 0.03, 0.03, 0.03, 0.36, 0.36, 0.36, 0.36
         !Config Help  =
         !Config Units = [ngN/m^2/s]
         CALL getin_p('EM_FACTOR_NO_WET',em_factor_no_wet)

         !Config Key   = EM_FACTOR_NO_DRY
         !Config Desc  = NOx emissions factor dry soil emissions and exponential dependancy factor 
         !Config if    = DIFFUCO_OK_INCA
         !Config Def   = 0., 8.60, 0.40, 0.22, 0.22, 0.22, 0.22, 0.22, 0.22, 2.65, 2.65, 2.65, 2.65
         !Config Help  =
         !Config Units = [ngN/m^2/s] 
         CALL getin_p('EM_FACTOR_NO_DRY',em_factor_no_dry)

         !Config Key   = LARCH
         !Config Desc  = Larcher 1991 SAI/LAI ratio
         !Config if    = DIFFUCO_OK_INCA 
         !Config Def   = 0., 0.015, 0.015, 0.003, 0.005, 0.005, 0.003, 0.005, 0.003, 0.005, 0.005, 0.008, 0.008
         !Config Help  =
         !Config Units = [-]  
         CALL getin_p('LARCH',Larch)
         
      ENDIF ! (active_flags%ok_inca)

      first_call = .FALSE.

   ENDIF !(first_call)

 END SUBROUTINE config_sechiba_pft_parameters
!
!=
!

!! ================================================================================================================================
!! SUBROUTINE   : config_stomate_pft_parameters 
!!
!>\BRIEF         This subroutine will read the imposed values for the stomate pft
!! parameters. It is not called if IMPOSE_PARAM is set to NO.
!!
!! DESCRIPTION  : None
!!
!! RECENT CHANGE(S): None
!!
!! MAIN OUTPUT VARIABLE(S): None
!!
!! REFERENCE(S) : None
!!
!! FLOWCHART    : None
!! \n
!_ ================================================================================================================================

 SUBROUTINE config_stomate_pft_parameters

   IMPLICIT NONE
   
   !! 0. Variables and parameters declaration

   !! 0.4 Local variable

   LOGICAL, SAVE ::  first_call = .TRUE.   !! To keep first call trace (true/false)
!$OMP THREADPRIVATE(first_call)
   INTEGER(i_std)               :: ivma,ivm!! index

!_ ================================================================================================================================

   IF (first_call) THEN
      
      !
      ! Vegetation structure
      !

      !Config Key   = SLA
      !Config Desc  = specif leaf area 
      !Config if    = OK_STOMATE
      !Config Def   = 1.5E-2, 1.53E-2, 2.6E-2, 9.26E-3, 2E-2, 2.6E-2, 9.26E-3, 2.6E-2, 1.9E-2, 2.6E-2, 2.6E-2, 2.6E-2, 2.6E-2
      !Config Help  =
      !Config Units = [m^2/gC]
      CALL getin_p('SLA',sla)

      !Config Key   = IS_TROPICAL
      !Config Desc  = PFT IS TROPICAL 
      !Config if    = OK_STOMATE
      !Config Def   = FALSE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('IS_TROPICAL',is_tropical)

      !Config Key   = IS_TEMPERATE
      !Config Desc  = PFT IS TEMPERATE 
      !Config if    = OK_STOMATE
      !Config Def   = FALSE, FALSE, FALSE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE 
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('IS_TEMPERATE',is_temperate)

      !Config Key   = IS_BOREAL
      !Config Desc  = PFT IS BOREAL 
      !Config if    = OK_STOMATE
      !Config Def   = FALSE, FALSE, FALSE, FALSE, FALSE, FALSE,TRUE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE 
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('IS_BOREAL',is_boreal)

      !
      ! Photosynthesis
      !

!!$      !Config Key   = TPHOTO_MIN_A
!!$      !Config Desc  = minimum photosynthesis temperature, constant a of ax^2+bx+c (deg C), tabulated
!!$      !Config if    = OK_STOMATE
!!$      !Config Def   = undef,  0., 0., 0., 0., 0., 0.,  0., 0.,  0.0025, 0., 0., 0. 
!!$      !Config Help  = a coefficient of the quadratic relationship that determines the minimal temperature 
!!$      !Config         below which there is no more photosynthesis 
!!$      !Config Units = [-]
!!$      CALL getin_p('TPHOTO_MIN_A',tphoto_min_a)
!!$
!!$      !Config Key   = TPHOTO_MIN_B
!!$      !Config Desc  = minimum photosynthesis temperature, constant b of ax^2+bx+c (deg C), tabulated
!!$      !Config if    = OK_STOMATE
!!$      !Config Def   = undef,  0.,  0., 0., 0., 0., 0., 0., 0., 0.1, 0.,0.,0.
!!$      !Config Help  = b coefficient of the quadratic relationship that determines the minimal temperature 
!!$      !Config         below which there is no more photosynthesis 
!!$      !Config Units = [-]
!!$      CALL getin_p('TPHOTO_MIN_B',tphoto_min_b)
!!$
!!$      !Config Key   = TPHOTO_MIN_C
!!$      !Config Desc  = minimum photosynthesis temperature, constant c of ax^2+bx+c (deg C), tabulated
!!$      !Config if    = OK_STOMATE
!!$      !Config Def   = undef,  2., 2., -4., -3.,-2.,-4., -4., -4., -3.25, 13.,-5.,13.
!!$      !Config Help  = Offset the quadratic relationship that determines the minimal temperature 
!!$      !Config         below which there is no more photosynthesis  
!!$      !Config Units = [-]
!!$      CALL getin_p('TPHOTO_MIN_C',tphoto_min_c)
!!$
!!$      !Config Key   = TPHOTO_OPT_A
!!$      !Config Desc  = optimum photosynthesis temperature, constant a of ax^2+bx+c (deg C), tabulated
!!$      !Config if    = OK_STOMATE
!!$      !Config Def   = undef, 0., 0., 0., 0., 0., 0., 0., 0., 0.0025, 0., 0., 0. 
!!$      !Config Help  = a coefficient of the quadratic relationship that determines the optimal temperature 
!!$      !Config         controling Vcmax/Vjmax = f(T)
!!$      !Config Units = [-]
!!$      CALL getin_p('TPHOTO_OPT_A',tphoto_opt_a)
!!$
!!$      !Config Key   = TPHOTO_OPT_B
!!$      !Config Desc  = optimum photosynthesis temperature, constant b of ax^2+bx+c (deg C), tabulated
!!$      !Config if    = OK_STOMATE
!!$      !Config Def   = undef, 0., 0., 0., 0., 0., 0., 0., 0., 0.25, 0., 0., 0.  
!!$      !Config Help  = b coefficient of the quadratic relationship that determines the optimal temperature 
!!$      !Config         controling Vcmax/Vjmax = f(T)
!!$      !Config Units = [-]
!!$      CALL getin_p('TPHOTO_OPT_B',tphoto_opt_b)
!!$
!!$      !Config Key   = TPHOTO_OPT_C
!!$      !Config Desc  = optimum photosynthesis temperature, constant c of ax^2+bx+c (deg C), tabulated
!!$      !Config if    = OK_STOMATE
!!$      !Config Def   = undef, 37., 37., 25., 32., 26., 25., 25., 25., 27.25, 36., 30., 36.
!!$      !Config Help  = Offset the quadratic relationship that determines the optimal temperature 
!!$      !Config         controling Vcmax/Vjmax = f(T)
!!$      !Config Units = [-]
!!$      CALL getin_p('TPHOTO_OPT_C',tphoto_opt_c)
!!$
!!$      !Config Key   = TPHOTO_MAX_A
!!$      !Config Desc  = maximum photosynthesis temperature, constant a of ax^2+bx+c (deg C), tabulated
!!$      !Config if    = OK_STOMATE
!!$      !Config Def   = undef,  0., 0., 0., 0., 0., 0., 0., 0., 0.00375, 0., 0., 0.
!!$      !Config Help  = a coefficient of the quadratic relationship that determines the maximal temperature
!!$      !Config         beyond which there is no more photosynthesis
!!$      !Config Units = [-]
!!$      CALL getin_p('TPHOTO_MAX_A',tphoto_max_a)
!!$
!!$      !Config Key   = TPHOTO_MAX_B
!!$      !Config Desc  = maximum photosynthesis temperature, constant b of ax^2+bx+c (deg C), tabulated
!!$      !Config if    = OK_STOMATE
!!$      !Config Def   = undef, 0., 0., 0., 0., 0., 0., 0., 0.,0.35, 0., 0., 0.   
!!$      !Config Help  = b coefficient of the quadratic relationship that determines the maximal temperature
!!$      !Config         beyond which there is no more photosynthesis
!!$      !Config Units = [-]
!!$      CALL getin_p('TPHOTO_MAX_B',tphoto_max_b)
!!$
!!$      !Config Key   = TPHOTO_MAX_C
!!$      !Config Desc  = maximum photosynthesis temperature, constant c of ax^2+bx+c (deg C), tabulated 
!!$      !Config if    = OK_STOMATE
!!$      !Config Def   = undef, 55., 55.,38., 48.,38.,38., 38., 38., 41.125, 55., 45., 55.  
!!$      !Config Help  = Offset the quadratic relationship that determines the maximal temperature
!!$      !Config         beyond which there is no more photosynthesis
!!$      !Config Units = [-]
!!$      CALL getin_p('TPHOTO_MAX_C',tphoto_max_c)

      !
      ! Allocation - stomate
      !
      !
      !Config Key   = S0 
      !Config Desc  = Standard sapwood allocation 
      !Config If    = OK_STOMATE 
      !Config Def   = undef, .25, .25, .30, .30, .30, .30, .30, .30, .30, .30, .30, .30
      !Config Help  = 
      !Config Units = [-]    
      CALL getin_p('S0',S0)

      !
      ! Respiration - stomate
      !

      !Config Key   = MAINT_RESP_SLOPE_C
      !Config Desc  = slope of maintenance respiration coefficient (1/K), constant c of aT^2+bT+c , tabulated
      !Config if    = OK_STOMATE
      !Config Def   = undef, .20, .20, .16, .16, .16, .16, .16, .16, .16, .12, .16, .12 
      !Config Help  = Offset of the temperature quadratic function that determines the 
      !Config         slope of the function between temperature and maintenance respiration.
      !Config Units = [-]
      CALL getin_p('MAINT_RESP_SLOPE_C',maint_resp_slope_c) 

      !Config Key   = MAINT_RESP_SLOPE_B
      !Config Desc  = slope of maintenance respiration coefficient (1/K), constant b of aT^2+bT+c , tabulated
      !Config if    = OK_STOMATE
      !Config Def   = undef, .0, .0, .0, .0, .0, .0, .0, .0, -.00133, .0, -.00133, .0 
      !Config Help  = b coefficient of the temperature quadratic function that determines the 
      !Config         slope of the function between temperature and maintenance respiration.
      !Config Units = [-]
      CALL getin_p('MAINT_RESP_SLOPE_B',maint_resp_slope_b)

      !Config Key   = MAINT_RESP_SLOPE_A
      !Config Desc  = slope of maintenance respiration coefficient (1/K), constant a of aT^2+bT+c , tabulated
      !Config if    = OK_STOMATE
      !Config Def   = undef, .0, .0, .0, .0, .0, .0, .0, .0, .0, .0, .0, .0    
      !Config Help  = a coefficient of the temperature quadratic function that determines the 
      !Config         slope of the function between temperature and maintenance respiration.
      !Config Units = [-]
      CALL getin_p('MAINT_RESP_SLOPE_A',maint_resp_slope_a)

      !Config Key   = CM_ZERO_LEAF
      !Config Desc  = maintenance respiration coefficient at 0 deg C, for leaves, tabulated
      !Config if    = OK_STOMATE
      !Config Def   = undef, 2.35E-3, 2.62E-3, 1.01E-3, 2.35E-3, 2.62E-3, 1.01E-3,2.62E-3, 2.05E-3, 2.62E-3, 2.62E-3, 2.62E-3, 2.62E-3
      !Config Help  =
      !Config Units = [g/g/day]
      CALL getin_p('CM_ZERO_LEAF',cm_zero_leaf)

      !Config Key   = CM_ZERO_SAPABOVE
      !Config Desc  = maintenance respiration coefficient at 0 deg C,for sapwood above, tabulated
      !Config if    = OK_STOMATE
      !Config Def   = undef, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4
      !Config Help  =
      !Config Units = [g/g/day]
      CALL getin_p('CM_ZERO_SAPABOVE',cm_zero_sapabove)

      !Config Key   = CM_ZERO_SAPBELOW
      !Config Desc  = maintenance respiration coefficient at 0 deg C, for sapwood below, tabulated
      !Config if    = OK_STOMATE
      !Config Def   = undef, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4 
      !Config Help  =
      !Config Units = [g/g/day]
      CALL getin_p('CM_ZERO_SAPBELOW',cm_zero_sapbelow)

      !Config Key   = CM_ZERO_HEARTABOVE
      !Config Desc  = maintenance respiration coefficient at 0 deg C, for heartwood above, tabulated
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0. 
      !Config Help  =
      !Config Units = [g/g/day]
      CALL getin_p('CM_ZERO_HEARTABOVE',cm_zero_heartabove)

      !Config Key   = CM_ZERO_HEARTBELOW
      !Config Desc  = maintenance respiration coefficient at 0 deg C,for heartwood below, tabulated
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0. 
      !Config Help  =
      !Config Units = [g/g/day] 
      CALL getin_p('CM_ZERO_HEARTBELOW',cm_zero_heartbelow)

      !Config Key   = CM_ZERO_ROOT
      !Config Desc  = maintenance respiration coefficient at 0 deg C, for roots, tabulated
      !Config if    = OK_STOMATE
      !Config Def   = undef,1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3,1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3
      !Config Help  =
      !Config Units = [g/g/day] 
      CALL getin_p('CM_ZERO_ROOT',cm_zero_root)

      !Config Key   = CM_ZERO_FRUIT
      !Config Desc  = maintenance respiration coefficient at 0 deg C, for fruits, tabulated
      !Config if    = OK_STOMATE
      !Config Def   = undef, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4,1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4    
      !Config Help  =
      !Config Units = [g/g/day] 
      CALL getin_p('CM_ZERO_FRUIT',cm_zero_fruit)

      !+++CHECK+++
      ! Default values depend on the growth routine
      !Config Key   = CM_ZERO_CARBRES
      !Config Desc  = maintenance respiration coefficient at 0 deg C, for carbohydrate reserve, tabulated
      !Config if    = OK_STOMATE
      !Config Def   = undef, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4,1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4
      !Config Help  =
      !Config Units = [g/g/day] 
      CALL getin_p('CM_ZERO_CARBRES',cm_zero_carbres)

      !Config Key   = CM_ZERO_LABILE
      !Config Desc  = Caution, depends on the allocation scheme. Maintenance respiration coefficient at 0 deg C, for the labile pool, tabulated
      !Config if    = OK_STOMATE
      !Config Def   = undef, 3.36E-2, 3.36E-2, 3.36E-2, 3.36E-2, 3.36E-2, 3.36E-2, 3.36E-2, 3.36E-2, 3.36E-2, 3.36E-2, 3.36E-2, 3.36E-2 
      !Config Help  =
      !Config Units = [g/g/day] 
      CALL getin_p('CM_ZERO_LABILE',cm_zero_labile)
      
      !Config Key   = COEFF_MAINT_INIT
      !Config Desc  = initial values for maintenance respiration coefficient, used in functional allocation at 0 deg C
      !Config if    = OK_STOMATE
      !Config Def   = undef, 0.022, 0.022, 0.021, 0.033, 0.033, 0.033, 0.033, 0.033, 0.033, 0.011, 0.011, 0.011
      !Config Help  =
      !Config Units = [g/g/day] 
      CALL getin_p('COEFF_MAINT_INIT',coeff_maint_init)

      !Config Key   = FRAC_GROWTHRESP 
      !Config Desc  = Depends on the allocation scheme 
      !Config if    = 
      !Config Def   = 0.28, 0.28, 0.28, 0.28, 0.28, 0.28, 0.28, 0.28, 0.28, 0.28, 0.28, 0.28, 0.28 
      !Config Help  = 
      !Config Units = 
      CALL getin_p("FRAC_GROWTHRESP",frac_growthresp)

      !Config Key   = GPP_TO_LABILE 
      !Config Desc  = Depends on the allocation scheme 
      !Config if    = 
      !Config Def   = 1., 3., 1., 1., 3., 1., 3., 3., 3., 3., 3., 3. 
      !Config Help  = 
      !Config Units = 
      CALL getin_p("GPP_TO_LABILE",gpp_to_labile)

      !
      ! Stand structure - stomate
      !

      !Config Key   = PIPE_DENSITY 
      !Config Desc  = 
      !Config if    = 
      !Config Def   = undef, 3.e5, 3.e5, 2.e5, 3.e5, 3.e5, 2.e5, 3.e5, 2.e5, 2.e5, 2.e5, 2.e5, 2.e5
      !Config Help  = 
      !Config Units = 
      CALL getin_p("PIPE_DENSITY",pipe_density)

      !Config Key   = PIPE_TUNE1
      !Config Desc  = crown area = pipe_tune1. stem diameter**pipe_tune_exp_coeff (Reinicke's theory)
      !Config If    = OK_STOMATE 
      !Config Def   = undef, 100., 100., 100., 100., 100., 100., 100., 100., 0., 0., 0., 0. 
      !Config Help  = 
      !Config Units = [-]    
      CALL getin_p('PIPE_TUNE1',pipe_tune1)
      
      !Config Key   = PIPE_TUNE2
      !Config Desc  = height=pipe_tune2 * diameter**pipe_tune3
      !Config If    = OK_STOMATE 
      !Config Def   = undef, 40., 40., 40., 40., 40., 40., 40., 40., 0., 0., 0., 0.  
      !Config Help  = 
      !Config Units = [-]      
      CALL getin_p('PIPE_TUNE2',pipe_tune2) 
      
      !Config Key   = PIPE_TUNE3
      !Config Desc  = height=pipe_tune2 * diameter**pipe_tune3
      !Config If    = OK_STOMATE 
      !Config Def   = undef, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0., 0., 0., 0.   
      !Config Help  = 
      !Config Units = [-]    
      CALL getin_p('PIPE_TUNE3',pipe_tune3)
      
      !Config Key   = PIPE_TUNE4
      !Config Desc  = needed for stem diameter
      !Config If    = OK_STOMATE 
      !Config Def   = undef, 0.3, 0.3, 0.3, 0.3, 0.3, 0.3, 0.3, 0.3, 0., 0., 0., 0.
      !Config Help  = 
      !Config Units = [-]  
      CALL getin_p('PIPE_TUNE4',pipe_tune4)

      !Config Key   = TREE_FF
      !Config Desc  = Tree form factor reducing the volume of a cylinder
      !               to the real volume of the tree shape (including the 
      !               branches)
      !Config If    = OK_STOMATE 
      !Config Def   = undef, 0.6, 0.6, 0.6, 0.6, 0.6, 0.8, 0.8, 0.8, 0., 0., 0., 0.
      !Config Help  = 
      !Config Units = [-]  
      CALL getin_p('TREE_FF',tree_ff)
      
      !Config Key   = PIPE_K1 
      !Config Desc  = 
      !Config If    = OK_STOMATE 
      !Config Def   = undef, 8.e3, 8.e3, 8.e3, 8.e3, 8.e3, 8.e3, 8.e3, 8.e3, 0., 0., 0., 0. 
      !Config Help  = 
      !Config Units = [-]   
      CALL getin_p('PIPE_K1',pipe_k1)
       
      !Config Key   = PIPE_TUNE_EXP_COEFF 
      !Config Desc  = pipe tune exponential coeff 
      !Config If    = OK_STOMATE 
      !Config Def   = undef, 1.6, 1.6, 1.6, 1.6, 1.6, 1.6, 1.6, 1.6, 0., 0., 0., 0.  
      !Config Help  = 
      !Config Units = [-]   
      CALL getin_p('PIPE_TUNE_EXP_COEFF',pipe_tune_exp_coeff)
      
      !Config Key   = MASS_RATIO_HEART_SAP 
      !Config Desc  = mass ratio (heartwood+sapwood)/heartwood 
      !Config If    = OK_STOMATE 
      !Config Def   = undef, 3., 3., 3., 3., 3., 3., 3., 3., 0., 0., 0., 0.  
      !Config Help  = 
      !Config Units = [-]   
      CALL getin_p('MASS_RATIO_HEART_SAP',mass_ratio_heart_sap)

      !Config Key   = LAI_TO_HEIGHT
      !Config Desc  = Convertion factor from lai to vegetation height for grasses and crops
      !Config if    = OK_STOMATE, OK_FUNCTIONAL_ALLOCATION
      !Config Def   = undef, 
      !Config Help  = undef, undef, undef, undef, undef, undef, undef, undef, undef, 0.2, 0.5, 0.2, 0.5
      !Config Units = [m m2 m-2] 
      CALL getin_p('LAI_TO_HEIGHT',lai_to_height)


      !Config Key   = CANOPY_COVER
      !Config Desc  = Test values for canopy cover
      !Config if    = OK_STOMATE, OK_FUNCTIONAL_ALLOCATION
      !Config Def   = undef, 0.9, 0.9, 0.7, 0.7, 0.7, 0.6, 0.5, 0.5, 0.9, 0.9, 0.9, 0.9
      !Config Help  =
      !Config Units = [-] 
      CALL getin_p('CANOPY_COVER',canopy_cover)
      
      !
      ! Growth - Resource limitation stomate
      !
      
      !
      ! Growth - Functional allocation stomate 
      !

      !Config Key   = CN_LEAF_PRESCRIBED
      !Config Desc  = 
      !Config if    = 
      !Config Def   = undef, 29., 29., 29., 29., 29., 29., 29., 29., 29., 29., 29., 29.
      !Config Help  = 
      !Config Units = 
      CALL getin_p("CN_LEAF_PRESCRIBED",cn_leaf_prescribed)

      !Config Key   = FCN_WOOD
      !Config Desc  = CN of wood for allocation, relative to leaf CN according to stich et al 2003
      !Config if    = OK_STOMATE
      !Config Def   = undef, .087, .087, .087, .087, .087, .087, .087, .087, 1., 1., 1.
      !Config Help  =
      !Config Units = [-] 
      CALL getin_p('FCN_WOOD',fcn_wood)  
   
      !Config Key   = FCN_ROOT
      !Config Desc  = CN roots for allocation, relative to leaf CN according to stich et al 2003
      !Config if    = OK_STOMATE
      !Config Def   = undef, 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.
      !Config Help  =
      !Config Units = [-] 
      CALL getin_p('FCN_ROOT',fcn_root) 

      !Config Key   = K_LATOSA_MAX
      !Config Desc  = Maximum leaf-to-sapwood area ratio
      !Config if    = OK_STOMATE
      !Config Def   = (undef, 5., 5., 5., 3., 5., 5., 5., 5., undef, undef, undef, undef)*1.e3
      !Config Help  =
      !Config Units = [-] 
      CALL getin_p('K_LATOSA_MAX',k_latosa_max)

      !Config Key   = K_LATOSA_MIN
      !Config Desc  = Minimum leaf-to-sapwood area ratio
      !Config if    = OK_STOMATE
      !Config Def   = (undef, 5., 5., 5., 3., 5., 5., 5., 5., undef, undef, undef, undef)*1.e3
      !Config Help  =
      !Config Units = [-] 
      CALL getin_p('K_LATOSA_MIN',k_latosa_min) 

      !Config Key   = FRUIT_ALLOC
      !Config Desc  = Guestimates - should be confirmed
      !Config if    = OK_STOMATE
      !Config Def   = (undef, 0.1, 0.1, 0.1, 0.1, 0.1, 0.1, 0.1, 0.1, 0., 0., 0., 0.)
      !Config Help  =
      !Config Units = [-] 
      CALL getin_p('FRUIT_ALLOC',fruit_alloc)

      !Config Key   = LAI_MAX_TO_HAPPY
      !Config Desc  = 
      !Config If    = OK_STOMATE 
      !Config Def   = undef, 0.5, 0.5, 0.5, 0.5, 0.4, 0.5, 0.36, 0.35, 0.35, 0.5, 0.5, 0.5 
      !Config Help  = Multiplicative factor of lai_max that determines
      !Config         the threshold value of LAI below which the carbohydrate
      !Config         reserve is used.
      !Config Units = [-]  
      CALL getin_p('LAI_MAX_TO_HAPPY',lai_max_to_happy)
       !


      !Config Key   = NMAXTREES
      !Config Desc  = number of seedlings planted at the start of a rotation
      !Config if    = FOREST_MANAGEMENT 
      !Config Def   = (undef, 10., 10., 10., 10., 10., 2., 2., 2., 10., 10., 10., 10.)*1.e3
      !Config Help  = 
      !Config Units = [trees ha-1]
      CALL getin_p("NMAXTREES",nmaxtrees)

      !Config Key   = HEIGHT_INIT_MIN
      !Config Desc  = 
      !Config if    = FUNCTIONAL ALLOCATION 
      !Config Def   = undef, 2, 2, 2, 2, 2, 3, 3, 3, 3, 0.1, 0.1, 0.1, 0.1
      !Config Help  = 
      !Config Units = [m]
      CALL getin_p("HEIGHT_INIT_MIN",height_init_min)

      !Config Key   = HEIGHT_INIT_MAX
      !Config Desc  = 
      !Config if    = FUNCTIONAL ALLOCATION 
      !Config Def   = undef, 3, 3, 3, 3, 3, 4, 4, 4, 4, 0.2, 0.2, 0.2, 0.2
      !Config Help  = 
      !Config Units = [m]
      CALL getin_p("HEIGHT_INIT_MAX",height_init_max)

      !Config Key   = ALPHA_SELF_THINNING
      !Config Desc  = 
      !Config if    = FUNCTION NMAX 
      !Config Def   = undef, 3000, 3000, 1462, 2262, 1900, 960, 939, 1046, undef, undef, undef, undef
      !Config Help  = 
      !Config Units = [-]
      CALL getin_p("ALPHA_SELF_THINNING",alpha_self_thinning)

      !Config Key   = BETA_SELF_THINNING
      !Config Desc  = 
      !Config if    = FUNCTION NMAX 
      !Config Def   = undef, -0.57, -0.57, -0.55, -0.61, -0.58, -0.55, -0.56, -0.56, undef, undef, undef, undef
      !Config Help  = 
      !Config Units = [-]
      CALL getin_p("BETA_SELF_THINNING",beta_self_thinning)

      !Config Key   = FUELWOOD_DIAMETER
      !Config Desc  = Diameter below which harvest will be used as fuelwood
      !Config if    = 
      !Config Def   = undef, 0.3, 0.3, 0.2, 0.3, 0.3, 0.2, 0.2, 0.2, undef, undef, undef, undef
      !Config Help  = 
      !Config Units = [m]
      CALL getin_p("FUELWOOD_DIAMETER",fuelwood_diameter)
      
      !Config Key   = COPPICE_KILL_BE_WOOD
      !Config Desc  = The fraction of belowground wood killed during coppicing
      !Config if    = 
      !Config Def   = undef, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, undef, undef, undef, undef
      !Config Help  = 
      !Config Units = [m]
      CALL getin_p("COPPICE_KBEW",coppice_kill_be_wood)
      !
      ! Hydraulic architecture - sechiba?
      !

      !Config Key   = K_ROOT
      !Config Desc  = Fine root specific conductivity
      !Config if    = OK_STOMATE
      !Config Def   = (undef, 4., 4., 4., 4., 4., 4., 4., 4., 50., 50., 50., 50.)*1.e-7 
      !Config Help  =
      !Config Units = [m^{3} kg^{-1} s^{-1} MPa^{-1}] 
      CALL getin_p('K_ROOT',k_root) 
    
      !Config Key   = K_SAP
      !Config Desc  = Sapwood specific conductivity
      !Config if    = OK_STOMATE
      !Config Def   = (undef, 50., 10., 8., 5., 30., 8., 20., 8., undef, undef, undef, undef)*1.e-4
      !Config Help  =
      !Config Units = [m^{2} s^{-1} MPa^{-1}] 
      CALL getin_p('K_SAP',k_sap)

      !Config Key   = K_LEAF
      !Config Desc  = Leaf conductivity
      !Config if    = OK_STOMATE
      !Config Def   = (undef, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5, 1.5)*1.e-7
      !Config Help  =
      !Config Units = [m s^{-1} MPa^{-1})] 
      CALL getin_p('K_LEAF',k_leaf)

      !Config Key   = PHI_LEAF
      !Config Desc  = Minimal leaf potential
      !Config if    = OK_STOMATE, 11-LAYERS, FUNCTIONAL ALLOCATION
      !Config Def   = undef, -2.2, -2.2, -2.2, -3.5, -2.2, -2.2, -2.2, -2.2, -2.2, -2.2, -2.2, -2.2
      !Config Help  =
      !Config Units = [MPa] 
      CALL getin_p('PHI_LEAF',phi_leaf)

      !Config Key   = PHI_50
      !Config Desc  = Sapwood leaf water potential that causes 50% loss of xylem conductivity through cavitation
      !Config if    = OK_STOMATE, 11-LAYERS, FUNCTIONAL ALLOCATION
      !Config Def   = undef, -0.3, -1.3, -2.0, -1.7, -1.0, -2.0, -1.0, -2.0, undef, undef, undef, undef
      !Config Help  =
      !Config Units = [m s^{-1} MPa^{-1})] 
      CALL getin_p('PHI_50',phi_50)      
      
      !Config Key   = C_CAVITATION
      !Config Desc  = Shape parameter for loss of conductance
      !Config if    = OK_STOMATE, 11-LAYERS, FUNCTIONAL ALLOCATION
      !Config Def   = undef, 5., 3., 3., 3., 3., 3., 3., 3., undef, undef, undef, undef  
      !Config Help  =
      !Config Units = [-] 
      CALL getin_p('C_CAVITATION',c_cavitation)

      !Config Key   = PHI_SOIL_TUNE
      !Config Desc  = Additive tuning parameter to account for soil-root interactions
      !Config if    = OK_STOMATE, 11-LAYERS, FUNCTIONAL ALLOCATION, HYDRAOL_ARCHITECTURE
      !Config Def   = undef, 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0. 
      !Config Help  =
      !Config Units = [MPa] 
      CALL getin_p('PHI_SOIL_TUNE',phi_soil_tune)

      !Config Key   = LAI_HAPPY
      !Config Desc  = The value of LAI below which carbohydrate reserves will be used. Shape parameter for loss of conductance
      !Config if    = OK_STOMATE, FUNCTIONAL ALLOCATION
      !Config Def   = undef, 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.  
      !Config Help  =
      !Config Units = [m^{2} m^{-2}] 
      CALL getin_p('LAI_HAPPY',lai_happy) 

!--------------------------------------------------------------------------------------------------------------------------------
      ! tzjh hydraulic architecture

      !Config Key   = GPSI
      !Config Desc  = gs vs psi_leaf curve parameter 
      !Config if    = OK_STOMATE 
      !Config Def   = undef, -1.2, -1.2, -1.2,-1.2, -1.2,-1.2,-1.2, -1.2,-1.2,-1.2,-1.2,-1.2   
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('GPSI',gpsi) 

      !Config Key   = GPSI_50
      !Config Desc  = psi_leaf at 50% stomatal closure 
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 2.5, 2.5, 2.5,2.5, 2.5,2.5,2.5, 2.5,2.5,2.5,2.5,2.5   
      !Config Help  =
      !Config Units = [-Mpa]
      CALL getin_p('GPSI_50',gpsi_50) 

      !Config Key   = GMAX
      !Config Desc  = maximum stomatal conductance 
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 1000., 1000., 1000.,1000., 1000.,1000.,1000., 1000.,1000.,1000.,1000.,1000.   
      !Config Help  =
      !Config Units = [mmol m^{-2}s^{-1}]
      CALL getin_p('GMAX',gmax) 
      
      !Config Key   = GMIN
      !Config Desc  = minimum stomatal conductance 
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 10., 10., 10.,10., 10.,10.,10., 10.,10.,10.,10.,10.   
      !Config Help  =
      !Config Units = [mmol m^{-2}s^{-1}]
      CALL getin_p('GMIN',gmin) 

      !Config Key   = KMAX_LEAF
      !Config Desc  = maximum hydraulic conductivity of leaf    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 10., 10., 10.,10., 10.,10.,10., 10.,10.,10.,10.,10.   
      !Config Help  =
      !Config Units = [mmol m^{-2}s^{-1} MPa^{-1}]
      CALL getin_p('KMAX_LEAF',kmax_leaf) 

      !Config Key   = KMAX_STEM
      !Config Desc  = maximum hydraulic conductivity of stem
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 10., 10., 10.,10., 10.,10.,10., 10.,10.,10.,10.,10.   
      !Config Help  =
      !Config Units = [mmol m^{-2}s^{-1} MPa^{-1}]
      CALL getin_p('KMAX_stem',kmax_stem) 

      !Config Key   = KMAX_ROOT
      !Config Desc  = maximum hydraulic conductivity of root    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 10., 10., 10.,10., 10.,10.,10., 10.,10.,10.,10.,10.   
      !Config Help  =
      !Config Units = [mmol m^{-2}s^{-1} MPa^{-1}]
      CALL getin_p('KMAX_ROOT',kmax_root) 

      !Config Key   = A_LEAF
      !Config Desc  = kleaf vs. psi_leaf curve parameter    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, -1.2, -1.2, -1.2,-1.2, -1.2,-1.2,-1.2, -1.2,-1.2,-1.2,-1.2,-1.2   
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('A_LEAF',a_leaf) 

      !Config Key   = A_STEM
      !Config Desc  = kstem vs. psi_stem curve parameter    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, -1.2, -1.2, -1.2,-1.2, -1.2,-1.2,-1.2, -1.2,-1.2,-1.2,-1.2,-1.2   
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('A_STEM',a_stem) 

      !Config Key   = A_ROOT
      !Config Desc  = kroot vs. psi_root curve parameter    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, -1.2, -1.2, -1.2,-1.2, -1.2,-1.2,-1.2, -1.2,-1.2,-1.2,-1.2,-1.2   
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('A_ROOT',a_root) 

      !Config Key   = P50_LEAF
      !Config Desc  = psi_leaf at 50% loss of leaf hydraulic conductivity    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 2.5, 2.5, 2.5,2.5, 2.5,2.5,2.5, 2.5,2.5,2.5,2.5,2.5   
      !Config Help  =
      !Config Units = [-MPa]
      CALL getin_p('P50_LEAF',P50_leaf) 

      !Config Key   = P50_STEM
      !Config Desc  = psi_stem at 50% loss of leaf hydraulic conductivity    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 2.5, 2.5, 2.5,2.5, 2.5,2.5,2.5, 2.5,2.5,2.5,2.5,2.5   
      !Config Help  =
      !Config Units = [-MPa]
      CALL getin_p('P50_STEM',P50_stem) 

      !Config Key   = P50_ROOT
      !Config Desc  = psi_root at 50% loss of leaf hydraulic conductivity    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 2.5, 2.5, 2.5,2.5, 2.5,2.5,2.5, 2.5,2.5,2.5,2.5,2.5   
      !Config Help  =
      !Config Units = [-MPa]
      CALL getin_p('P50_ROOT',P50_root) 

      !Config Key   = WOOD_DENSITY
      !Config Desc  = g of stem dry mass per m3 of stem volume    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 645000, 645000, 645000,645000, 645000,645000,645000, 645000,645000,645000,645000,645000   
      !Config Help  =
      !Config Units = [g m^{-3}]
      CALL getin_p('WOOD_DENSITY',wood_density) 

      !Config Key   = W_DENSITY_STEM
      !Config Desc  = mmol H2O per m3 of stem volume    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 25000000, 25000000, 25000000,25000000, 25000000,25000000,25000000, 25000000,25000000,25000000,25000000,25000000   
      !Config Help  =
      !Config Units = [mmol m^{-3}]
      CALL getin_p('W_DENSITY_STEM',w_density_stem) 

      !Config Key   = ROOT_SHOOT_RATIO
      !Config Desc  = ratio of root mass to shoot mass    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 0.25, 0.25, 0.25,0.25, 0.25,0.25,0.25, 0.25,0.25,0.25,0.25,0.25   
      !Config Help  =
      !Config Units = [g g^{-1}]
      CALL getin_p('ROOT_SHOOT_RATIO',root_shoot_ratio) 

      !Config Key   = RWC_ROOT
      !Config Desc  = relative water content in the root    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 35, 35, 35,35, 35,35,35, 35,35,35,35,35   
      !Config Help  =
      !Config Units = [mmol g{-1}]
      CALL getin_p('RWC_ROOT',rwc_root) 
      
      !Config Key   = ROOT_DENSITY
      !Config Desc  = relative water content in the root    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 0.502, 0.502, 0.502,0.502, 0.502,0.502,0.502, 0.502,0.502,0.502,0.502,0.502   
      !Config Help  =
      !Config Units = [g cm{-3}]
      CALL getin_p('ROOT_DENSITY',root_density) 

      !Config Key   = LDMC
      !Config Desc  = leaf dry matter content    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 0.2, 0.2, 0.2,0.2, 0.2,0.2,0.2, 0.2,0.2,0.2,0.2,0.2   
      !Config Help  =
      !Config Units = [g g{-1}]
      CALL getin_p('LDMC',LDMC) 
   
      !Config Key   = SLA_HYDRO
      !Config Desc  = specific leaf area for use in the hydraulic architecture    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 16.6, 16.6, 16.6,16.6, 16.6,16.6,16.6, 16.6,16.6,16.6,16.6,16.6   
      !Config Help  =
      !Config Units = [m^{2} g{-1}]
      CALL getin_p('SLA_HYDRO',sla_hydro) 

      !Config Key   = CXYL
      !Config Desc  = stem capacitance    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 0.5, 0.5, 0.5,0.5, 0.5,0.5,0.5, 0.5,0.5,0.5,0.5,0.5   
      !Config Help  =
      !Config Units = [mmol mmol^{-1} MPa^{-1}]
      CALL getin_p('CXYL',cxyl) 

      !Config Key   = CR
      !Config Desc  = root capacitance    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 0.5, 0.5, 0.5,0.5, 0.5,0.5,0.5, 0.5,0.5,0.5,0.5,0.5   
      !Config Help  =
      !Config Units = [mmol mmol^{-1} MPa^{-1}]
      CALL getin_p('CR',cr) 

      !Config Key   = CL
      !Config Desc  = leaf capacitance    
      !Config if    = OK_STOMATE 
      !Config Def   = undef, 0.1, 0.1, 0.1,0.1, 0.1,0.1,0.1, 0.1,0.1,0.1,0.1,0.1   
      !Config Help  =
      !Config Units = [mmol mmol^{-1} MPa^{-1}]
      CALL getin_p('CL',cl) 
!-----------------------------------------------------------------------------------------------------------------

!
      ! Mortality - lpj_gap
      !
      !Config Key   = DEATH_DISTRIBUTION_FACTOR
      !Config Desc  = Shape parameter for tree mortality
      !Config if    = OK_STOMATE, FUNCTIONAL ALLOCATION
      !Config Def   = undef, 100., 100., 100., 100., 100., 100., 100., 100., undef, undef, undef, undef  
      !Config Help  =
      !Config Units = [-] 
      CALL getin_p('DEATH_DF',death_distribution_factor) 

      !Config Key   = NPP_RESET_VALUE
      !Config Desc  = The value longterm NPP is reset to after a non-tree stand dies. 
      !Config if    = OK_STOMATE, FUNCTIONAL ALLOCATION
      !Config Def   = undef, undef, undef, undef, undef, undef, undef, undef, undef, 500., 500., 500., 500.  
      !Config Help  =
      !Config Units = [-]       CALL getin_p('NPP_RESET_VALUE',npp_reset_value) 

      
      ! Fire - stomate
      !

      !Config Key   = FLAM
      !Config Desc  = flamability: critical fraction of water holding capacity
      !Config if    = OK_STOMATE
      !Config Def   = undef, .15, .25, .25, .25, .25, .25, .25, .25, .25, .25, .35, .35
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('FLAM',flam)

      !Config Key   = RESIST
      !Config Desc  = fire resistance
      !Config if    = OK_STOMATE
      !Config Def   = undef, .95, .90, .12, .50, .12, .12, .12, .12, .0, .0, .0, .0 
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('RESIST',resist)
     
      !
      ! Flux - LUC
      !

      !Config Key   = COEFF_LCCHANGE_s
      !Config Desc  = Coeff of biomass export for the year
      !Config if    = OK_STOMATE
      !Config Def   = undef, 0.897, 0.897, 0.597, 0.597, 0.597, 0.597, 0.597, 0.597, 0.597, 0.597, 0.597, 0.597 
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('COEFF_LCCHANGE_s',coeff_lcchange_s)

      !Config Key   = COEFF_LCCHANGE_m
      !Config Desc  = Coeff of biomass export for the decade
      !Config if    = OK_STOMATE
      !Config Def   = undef, 0.103, 0.103, 0.299, 0.299, 0.299, 0.299, 0.299, 0.299, 0.299, 0.403, 0.299, 0.403
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('COEFF_LCCHANGE_m',coeff_lcchange_m)

      !Config Key   = COEFF_LCCHANGE_l
      !Config Desc  = Coeff of biomass export for the century
      !Config if    = OK_STOMATE
      !Config Def   = undef, 0., 0., 0.104, 0.104, 0.104, 0.104, 0.104, 0.104, 0.104, 0., 0.104, 0.
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('COEFF_LCCHANGE_l',coeff_lcchange_l)
      
      !
      ! Phenology
      !

      !Config Key   = LAI_MAX
      !Config Desc  = maximum LAI, PFT-specific
      !Config if    = OK_STOMATE
      !Config Def   = undef, 7., 7., 5., 5., 5., 4.5, 4.5, 3.0, 2.5, 2.5, 5.,5. 
      !Config Help  =
      !Config Units = [m^2/m^2]
      CALL getin_p('LAI_MAX',lai_max)

      !Config Key   = PHENO_TYPE
      !Config Desc  = type of phenology, 0=bare ground 1=evergreen,  2=summergreen,  3=raingreen,  4=perennial
      !Config if    = OK_STOMATE
      !Config Def   = 0, 1, 3, 1, 1, 2, 1, 2, 2, 4, 4, 2, 3
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('PHENO_TYPE',pheno_type)

      !
      ! Phenology : Leaf Onset
      !

      !Config Key   = PHENO_GDD_CRIT_C
      !Config Desc  = critical gdd, tabulated (C), constant c of aT^2+bT+c
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, undef, undef, undef, undef, undef, undef, undef, 270., 400., 125., 400.
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('PHENO_GDD_CRIT_C',pheno_gdd_crit_c)

      !Config Key   = PHENO_GDD_CRIT_B
      !Config Desc  = critical gdd, tabulated (C), constant b of aT^2+bT+c
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, undef, undef, undef, undef, undef,undef, undef, 6.25, 0., 0., 0.
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('PHENO_GDD_CRIT_B',pheno_gdd_crit_b)

      !Config Key   = PHENO_GDD_CRIT_A
      !Config Desc  = critical gdd, tabulated (C), constant a of aT^2+bT+c
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, undef, undef, undef, undef, undef, undef, undef, 0.03125,  0., 0., 0.
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('PHENO_GDD_CRIT_A',pheno_gdd_crit_a)

      !Config Key   = NGD_CRIT
      !Config Desc  = critical ngd, tabulated. Threshold -5 degrees
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, undef, undef, undef, undef, undef, 0., undef, undef, undef, undef, undef
      !Config Help  = NGD : Number of Growing Days.
      !Config Units = [days]
      CALL getin_p('NGD_CRIT',ngd_crit)


      !Config Key   = OPTI_KPHENO_CRIT
      !Config Desc  = multiplicative factor to optimize gdd_crit
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, undef, undef, undef, 1.13, undef, 0.87, 1.08, 0.81, undef, undef, undef
      !Config Help  = 
      !Config Units = [-]
      CALL getin_p('OPTI_KPHENO_CRIT',opti_kpheno_crit)


      !Config Key   = NCDGDD_TEMP
      !Config Desc  = critical temperature for the ncd vs. gdd function in phenology
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, undef, undef, undef, 5., undef, 0., undef, undef, undef, undef, undef
      !Config Help  =
      !Config Units = [C] 
      CALL getin_p('NCDGDD_TEMP',ncdgdd_temp)

      !Config Key   = HUM_FRAC
      !Config Desc  = critical humidity (relative to min/max) for phenology
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, .5, undef, undef, undef, undef, undef,  undef, .5, .5, .5,.5     
      !Config Help  =
      !Config Units = [%]
      CALL getin_p('HUM_FRAC',hum_frac)

      !Config Key   = HUM_MIN_TIME
      !Config Desc  = minimum time elapsed since moisture minimum
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, 50., undef, undef, undef, undef, undef, undef, 35., 35., 75., 75.
      !Config Help  =
      !Config Units = [days]
      CALL getin_p('HUM_MIN_TIME',hum_min_time)

      !Config Key   = TAU_SAP
      !Config Desc  = sapwood longivety (sapwood -> heartwood conversion time)
      !Config if    = OK_STOMATE
      !Config Def   = undef, 730., 730., 730., 730., 730., 730., 730., 730., undef, undef, undef, undef
      !Config Help  =
      !Config Units = [days]
      CALL getin_p('TAU_SAP',tau_sap)

      !Config Key   = TAU_FRUIT
      !Config Desc  = fruit longivety
      !Config if    = OK_STOMATE
      !Config Def   = undef, 90., 90., 90., 90., 90., 90., 90., 90., undef, undef, undef, undef
      !Config Help  =
      !Config Units = [days]
      CALL getin_p('TAU_FRUIT',tau_fruit)

      !Config Key   = TAU_ROOT
      !Config Desc  = root longivety
      !Config if    = OK_STOMATE
      !Config Def   = undef, 256., 256., 256., 256., 256., 256., 256., 256., 256., 256., 256., 256.
      !Config Help  =
      !Config Units = [days]
      CALL getin_p('TAU_ROOT',tau_root)

      !Config Key   = TAU_LEAF
      !Config Desc  = leaf longivety
      !Config if    = OK_STOMATE
      !Config Def   = undef, 730., 180., 910., 730., 180., 910., 180., 180., 120., 120., 90., 90. 
      !Config Help  =
      !Config Units = [days]
      CALL getin_p('TAU_LEAF',tau_leaf)
  
      !Config Key   = ECUREUIL
      !Config Desc  = fraction of primary leaf and root allocation put into reserve
      !Config if    = OK_STOMATE
      !Config Def   = undef, .0, 1., .0, .0, 1., .0, 1., 1., 1., 1., 1., 1.
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('ECUREUIL',ecureuil)

      !Config Key   = ALLOC_MIN
      !Config Desc  = minimum allocation above/below = f(age) - 30/01/04 NV/JO/PF
      !Config if    = OK_STOMATE
      !Config Def   = undef, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, undef, undef, undef, undef 
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('ALLOC_MIN',alloc_min)

      !Config Key   = ALLOC_MAX
      !Config Desc  = maximum allocation above/below = f(age) - 30/01/04 NV/JO/PF
      !Config if    = OK_STOMATE
      !Config Def   = undef, 0.8, 0.8, 0.8, 0.8, 0.8, 0.8, 0.8, 0.8, undef, undef, undef, undef
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('ALLOC_MAX',alloc_max)

      !Config Key   = DEMI_ALLOC 
      !Config Desc  = mean allocation above/below = f(age) - 30/01/04 NV/JO/PF
      !Config if    = OK_STOMATE
      !Config Def   = undef, 5., 5., 5., 5., 5., 5., 5., 5., undef, undef, undef, undef
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('DEMI_ALLOC',demi_alloc)

      !
      ! Phenology : Senescence
      !
      !
      !Config Key   = LEAFFALL
      !Config Desc  = length of death of leaves, tabulated 
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, 10., undef, undef, 10., undef, 10., 10., 10., 10., 10., 10. 
      !Config Help  =
      !Config Units = [days]
      CALL getin_p('LEAFFALL',leaffall)

      !Config Key   = SENESCENCE_TYPE
      !Config Desc  = type of senescence, tabulated
      !Config if    = OK_STOMATE
      !Config Def   = none, none, dry, none, none, cold, none, cold, cold, mixed, mixed, mixed, mixed 
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('SENESCENCE_TYPE',senescence_type) 

      !Config Key   = SENESCENCE_HUM
      !Config Desc  = critical relative moisture availability for senescence
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, .3, undef, undef, undef, undef, undef, undef, .2, .2, .3, .2 
      !Config Help  =
      !Config Units = [-] 
      CALL getin_p('SENESCENCE_HUM',senescence_hum)

      !Config Key   = NOSENESCENCE_HUM
      !Config Desc  = relative moisture availability above which there is no humidity-related senescence
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, .8, undef, undef, undef, undef, undef, undef, .3, .3, .3, .3 
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('NOSENESCENCE_HUM',nosenescence_hum) 

      !Config Key   = MAX_TURNOVER_TIME
      !Config Desc  = maximum turnover time for grasse
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, undef, undef, undef, undef, undef, undef, undef,  80.,  80., 80., 80. 
      !Config Help  =
      !Config Units = [days]
      CALL getin_p('MAX_TURNOVER_TIME',max_turnover_time)

      !Config Key   = MIN_TURNOVER_TIME
      !Config Desc  = minimum turnover time for grasse 
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, undef, undef, undef, undef, undef, undef, undef, 10., 10., 10., 10. 
      !Config Help  =
      !Config Units = [days]
      CALL getin_p('MIN_TURNOVER_TIME',min_turnover_time)

      !Config Key   = MIN_LEAF_AGE_FOR_SENESCENCE
      !Config Desc  = minimum leaf age to allow senescence g
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, 90., undef, undef, 90., undef, 60., 60., 30., 30., 30., 30.
      !Config Help  =
      !Config Units = [days] 
      CALL getin_p('MIN_LEAF_AGE_FOR_SENESCENCE',min_leaf_age_for_senescence)

      !Config Key   = SENESCENCE_TEMP_C
      !Config Desc  = critical temperature for senescence (C), constant c of aT^2+bT+c, tabulated
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, undef, undef, undef, 12., undef, 7., 2., -1.375, 5., 5., 10.
      !Config Help  = Offset the quadratic relationship that determines the threshold temperature
      !Config         below which senescence occurs
      !Config Units = [-]
      CALL getin_p('SENESCENCE_TEMP_C',senescence_temp_c)

      !Config Key   = SENESCENCE_TEMP_B
      !Config Desc  = critical temperature for senescence (C), constant b of aT^2+bT+c ,tabulated
      !Config if    = OK_STOMATE 
      !Config Def   = undef, undef, undef, undef, undef, 0., undef, 0., 0., .1, 0., 0., 0.
      !Config Help  =
      !Config Units = [-]
      CALL getin_p('SENESCENCE_TEMP_B',senescence_temp_b)

      !Config Key   = SENESCENCE_TEMP_A
      !Config Desc  = critical temperature for senescence (C), constant a of aT^2+bT+c , tabulated
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, undef, undef, undef, 0., undef, 0., 0.,.00375, 0., 0., 0. 
      !Config Help  =
      !Config Units = [-] 
      CALL getin_p('SENESCENCE_TEMP_A',senescence_temp_a)

      !Config Key   = GDD_SENESCENCE
      !Config Desc  = minimum gdd to allow senescence of crops  
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, 950., 4000.
      !Config Help  =
      !Config Units = [days] 
      CALL getin_p("GDD_SENESCENCE", gdd_senescence)


      !
      ! CROPLAND MANAGEMENT
      !
      !Config Key   = HARVEST_RATIO
      !Config Desc  = Share of biomass that is harvested. This residual = 1 - harvest_ratio  
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, 0.5, 0.5
      !Config Help  =
      !Config Units = [unitless] 
      CALL getin_p("HARVEST_RATIO", harvest_ratio)

      !
      ! DGVM
      !

      !Config Key   = RESIDENCE_TIME
      !Config Desc  = residence time of trees
      !Config if    = OK_DGVM and NOT(LPJ_GAP_CONST_MORT)
      !Config Def   = undef, 30.0, 30.0, 40.0, 40.0, 40.0, 80.0, 80.0, 80.0, 0.0, 0.0, 0.0, 0.0 
      !Config Help  =
      !Config Units = [years]
      CALL getin_p('RESIDENCE_TIME',residence_time)


      ! added by yitong yao 07 Jan 2020 08:26 
      !Config Key   = PLC_KILL_FRAC
      !Config Desc  = fraction of killed trees due to plc >50
      !Config if 
      !Config Def   = undef, 0.01,0.01,0.01,0.01,0.01,0.01,0.01,...
      !Config Help  =
      !Config Units =[years]
      CALL getin_p('PLC_KILL_FRAC',plc_kill_frac)  

      ! added by yitong yao 07 Jan 2020 08:27 
      CALL getin_p('MOR_KILL_FRAC',mor_kill_frac)


      !Config Key   = TMIN_CRIT
      !Config Desc  = critical tmin, tabulated
      !Config if    = OK_STOMATE
      !Config Def   = undef,  0.0, 0.0, -30.0, -14.0, -30.0, -45.0, -45.0, undef, undef, undef, undef, undef
      !Config Help  = 
      !Config Units = [C]
      CALL getin_p('TMIN_CRIT',tmin_crit)

      !Config Key   = TCM_CRIT
      !Config Desc  = critical tcm, tabulated 
      !Config if    = OK_STOMATE
      !Config Def   = undef, undef, undef, 5.0, 15.5, 15.5, -8.0, -8.0, -8.0, undef, undef, undef, undef
      !Config Help  =
      !Config Units = [C]
      CALL getin_p('TCM_CRIT',tcm_crit)

      !Config Key   = MORTALITY_MIN
      !Config Desc  = Asymptotic mortality 
      !Config if    = OK_STOMATE, functional allocation, lpj_const_mort
      !Config Def   = undef, 0.01, 0.01, 0.01, 0.01, 0.01, 0.01, 0.01, 0.01, 0.01, 0.01, 0.01, 0.01
      !Config Help  =
      !Config Units = [year-1]
      CALL getin_p('MORTALITY_MIN',mortality_min)

      !Config Key   = MORTALITY_MAX
      !Config Desc  = Maximum mortality, tabulated 
      !Config if    = OK_STOMATE, functional allocation + lpj_const_mort
      !Config Def   = undef, 0.1, 0.1, 0.1, 0.1, 0.1, 0.1, 0.1, 0.1, 0.1, 0.1, 0.1, 0.1
      !Config Help  =
      !Config Units = [year-1]
      CALL getin_p('MORTALITY_MIN',mortality_min)

      !Config Key   = REF_MORTALITY
      !Config Desc  = Reference mortality, tabulated 
      !Config if    = OK_STOMATE, functional allocation + lpj_const_mort
      !Config Def   = undef, 0.035, 0.035, 0.035, 0.035, 0.035, 0.035, 0.035, 0.035, 0.035, 0.035, 0.035, 0.035
      !Config Help  =
      !Config Units = [year-1]
      CALL getin_p('REF_MORTALITY',ref_mortality)
      
      !Config Key   = TAU_HUM_GROWINGSEASON
      !Config Desc  = time integral for waterstress on KF (allocation)
      !Config if    = OK_STOMATE, functional allocation 
      !Config Def   = undef, tau_sap, tau_sap, tau_sap, tau_sap, tau_sap, tau_sap, tau_sap, tau_sap, tau_hum_growingseason_grass, 
      !                tau_hum_growingseason_grass, tau_hum_growingseason_grass, tau_hum_growingseason_grass  
      !Config Help  =
      !Config Units = [days]
      CALL getin_p('TAU_HUM_GROWINGSEASON',tau_hum_growingseason)

      !Config Key   = DENS_TARGET
      !Config Desc  = 
      !Config if    = OK_STOMATE, functional allocation
      !Config Def   = 0.0, 100.0, 100.0, 200.0, 100.0, 100.0, 200.0, 100.0, 200.0, 0.0, 0.0, 0.0, 0.0
      !Config Help  = 
      !Config Units = 
      CALL getin_p("DENS_TARGET",dens_target)

      ! Age classes
      ! I want to create a temporary array that indicates which "real" PFT starts
      ! on which index.  This could probably be put somewhere else, but this
      ! routine is only called once a year and this loop is not expensive.
      start_index(:)=-1
      nagec_pft(:)=-1
      DO ivma=1,nvmap
         ! The start index is just the first place we find this real PFT.
         DO ivm=1,nvm
            IF(agec_group(ivm) .EQ. ivma)THEN
               start_index(ivma)=ivm
               ! It is possible that not all forests will have multiple age classes.  For example,
               ! the species might have age classes but metaclasses (running outside Europe) might not.
               ! Let's check to see how many age classes each PFT has.  Right now, the only options
               ! are 1 or nagec, but this could be changed without too much difficulty.
               WRITE(numout,*) 'jifoez ',nagec,ivm,ivm+nagec-1
               IF((ivm+nagec-1) .LT. nvm)THEN
                  ! This first if loop prevents an out of bounds error
                  IF(agec_group(ivm+nagec-1) == ivma)THEN
                     nagec_pft(ivma)=nagec
                  ELSE
                     nagec_pft(ivma)=1
                  ENDIF
               ELSE
                  nagec_pft(ivma)=1
               ENDIF
               EXIT
            ENDIF
         ENDDO
      ENDDO
      ! Check to see if the calculation worked and we found indices for all of them.
      DO ivma=1,nvmap
         IF(start_index(ivma) .LT. 0)THEN
            WRITE(numout,*) 'Could not find a start index for one age class group!'
            WRITE(numout,*) 'Check the input file to make sure the following ivma appears in agec_group'
            WRITE(numout,*) 'ivma,nvmap',ivma,nvmap
            WRITE(numout,*) 'agec_group',agec_group(:)
            CALL ipslerr_p (3,'pft_parameters','pft_parameters_alloc','','')
         ENDIF
      ENDDO

      first_call = .FALSE.
       
   ENDIF !(first_call)
  
 END SUBROUTINE config_stomate_pft_parameters
!
!=
!
!! ================================================================================================================================
!! SUBROUTINE   : config_forest_management_parameters
!!
!>\BRIEF         This subroutine will read the imposed values for the forest management
!! parameters. It is not called if IMPOSE_PARAM is set to NO.
!!
!! DESCRIPTION  : None
!!
!! RECENT CHANGE(S): None
!!
!! MAIN OUTPUT VARIABLE(S): None
!!
!! REFERENCE(S) : None
!!
!! FLOWCHART    : None
!! \n
!_ ================================================================================================================================

 SUBROUTINE config_forest_manage_pft_parameters

   IMPLICIT NONE
   
   !! 0. Variables and parameters declaration

   !! 0.4 Local variable

   LOGICAL, SAVE ::  first_call = .TRUE.   !! To keep first call trace (true/false)
!$OMP THREADPRIVATE(first_call)
   REAL(r_std)   :: ss_dens_init           !! Sensitivity parameter for dens_init  
   REAL(r_std)   :: ss_branch_ratio        !! Sensitivity parameter for branch_ratio
 
!_ ================================================================================================================================

   !Config Key   = PLANTATION
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT
   !Config Def   = n, n, n, n, n, n, n, n, n, n, n, n, n
   !Config Help  = 
   !Config Units = 
   CALL getin_p("PLANTATION",plantation)

   !Config Key   = FM_ALLO_A
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = undef, 19.42, 19.42, 9.3, 19.42, 19.42, 9.3, 0.11, 0.35, undef, undef, undef, undef 
   !Config Help  = 
   !Config Units = 
   CALL getin_p("FM_ALLO_A",fm_allo_a)

   !Config Key   = FM_ALLO_C 
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT
   !Config Def   = undef, 0.11, 0.11, 0.35, 0.11, 0.11, 0.35, 0.11, 0.35, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("FM_ALLO_C",fm_allo_c)  

   !Config Key   = FM_ALLO_D 
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = undef, 0.13, 0.13, 0.3, 0.13, 0.13, 0.3, 0.13, 0.3, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("FM_ALLO_D",fm_allo_d) 
 
   !Config Key   = FM_ALLO_P
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = undef, 0.75, 0.75, 0.69, 0.75, 0.75, 0.69, 0.75, 0.69, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("FM_ALLO_P",fm_allo_p)

   !Config Key   = FM_ALLO_Q
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT
   !Config Def   = undef, -0.12, -0.12, -0.32, -0.12, -0.12, -0.32, -0.12, -0.32, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("FM_ALLO_Q",fm_allo_q)

   !Config Key   = ALLO_CROWN_A0
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = undef, -0.7602, -0.7602, -1.019, -0.7602, -0.7602, -1.019, -0.7602, -1.019, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("ALLO_CROWN_A0",allo_crown_a0)

   !Config Key   = ALLO_CROWN_A1
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = undef, 0.6672, 0.6672, 0.887, 0.6672, 0.6672, 0.887, 0.6672, 0.887, undef, undef, undef, undef 
   !Config Help  = 
   !Config Units = 
   CALL getin_p("ALLO_CROWN_A1",allo_crown_a1)

   !Config Key   = ALLO_CROWN_A2
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = undef, 0.12646, 0.12646, 0.188, 0.12646, 0.12646, 0.188, 0.12646, 0.188, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("ALLO_CROWN_A2",allo_crown_a2)

   !Config Key   = H_FIRST
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT
   !Config Def   = 0.0, 10.0, 10.0, 10.0, 10.0, 10.0, 10.0, 10.0, 10.0, 0.0, 0.0, 0.0, 0.0   
   !Config Help  = 
   !Config Units = 
   CALL getin_p("H_FIRST",h_first)

   !Config Key   = RECRUITMENT_LIGHT_THRESHOLD
   !Config Desc  = 
   !Config if    = 
   !Config Def   = undef, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0
   !Config Help  = 
   !Config Units = 
   CALL getin_p("RECRUITMENT_LIGHT_THRESHOLD",recruitment_light_threshold)
  
   !Config Key   = DIA_RECR
   !Config Desc  = 
   !Config if    = 
   !Config Def   = undef, 0.01, 0.01, 0.01, 0.01, 0.01, 0.01, 0.01, 0.01, 0.01, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("DIA_RECR",dia_recr)
   
   !Config Key   = HEI_RECR
   !Config Desc  = 
   !Config if    = 
   !Config Def   = undef, 1.8, 1.8, 1.8, 1.8, 1.8, 1.8, 1.8, 1.8, 1.8, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("HEI_RECR",hei_recr)

   
   ! Sensitivity analysis
   !
   !Config Key   = SS_DENS_INIT
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = 1.
   !Config Help  = 
   !Config Units = 
   ss_dens_init = 1.
   CALL getin_p("SS_DENS_INIT",ss_dens_init)

   !! Readjust nmaxtrees values according ss_dens_init value
   IF (nmaxtrees(1) >= 10) THEN
      nmaxtrees(:) = nmaxtrees(1)*ss_dens_init
   ENDIF
  
   !Config Key   = LARGEST_TREE_DIA
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = 0.0, 45.0, 45.0, 45.0, 45.0, 45.0, 45.0, 45.0, 45.0, 0.0, 0.0, 0.0, 0.0
   !Config Help  = 
   !Config Units = 
   CALL getin_p("LARGEST_TREE_DIA",largest_tree_dia)

   !Config Key   = THINSTRAT
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = 0.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 0.0, 0.0, 0.0, 0.0
   !Config Help  = 
   !Config Units = 
   CALL getin_p("THINSTRAT",thinstrat)

   !Config Key   = TAUMIN
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = 0.0, 0.01, 0.01, 0.01, 0.01, 0.01, 0.01, 0.01, 0.01, 0.0, 0.0, 0.0, 0.0
   !Config Help  = 
   !Config Units = 
   CALL getin_p("TAUMIN",taumin)

   !Config Key   = TAUMAX
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = 0.0, 0.05, 0.05, 0.05, 0.05, 0.05, 0.05, 0.05, 0.05, 0.0, 0.0, 0.0, 0.0
   !Config Help  = 
   !Config Units = 
   CALL getin_p("TAUMAX",taumax)

   !Config Key   = ALPHA_RDI_UPPER
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = undef, 3000, 3000, 592, 862, 504, 1287, 984, 589, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("ALPHA_RDI_UPPER",alpha_rdi_upper)

   !Config Key   = BETA_RDI_UPPER
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   =  undef, -0.57, -0.57, -0.46, -0.51, -0.44, -0.59, -0.57, -0.48, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("BETA_RDI_UPPER",beta_rdi_upper)
   
   !Config Key   = ALPHA_RDI_LOWER
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = undef, 2999, 2999, 433, 445, 369, 1022, 828, 385, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("ALPHA_RDI_LOWER",alpha_rdi_lower)

   !Config Key   = BETA_RDI_LOWER
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   =  undef, -0.57, -0.57, -0.46, -0.51, -0.44, -0.59, -0.57, -0.48, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("BETA_RDI_LOWER",beta_rdi_lower)

   !Config Key   = BRANCH_RATIO
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = 0.0, 0.38, 0.38, 0.25, 0.38, 0.38, 0.25, 0.38, 0.25, 0.0, 0.0, 0.0, 0.0  
   !Config Help  = 
   !Config Units = 
   CALL getin_p("BRANCH_RATIO",branch_ratio)

   !Config Key   = BRANCH_HARVEST
   !Config Desc  = The fraction of branches which are harvested during FM2 (the rest are left onsite)
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = 0.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 0.0, 0.0, 0.0, 0.0  
   !Config Help  = 
   !Config Units = 
   CALL getin_p("BRANCH_HARVEST",branch_harvest)

   ! Sensitivity parameter
   !
   !Config Key   = SS_BRANCH_RATIO
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = 
   !Config Help  = 
   !Config Units = 
   ss_branch_ratio = 1.
   CALL getin_p("SS_BRANCH_RATIO",ss_branch_ratio)

   !! Readjust branch_ratio values 
   branch_ratio(:) = ss_branch_ratio * branch_ratio(:)

   !Config Key   = DECL_FACTOR
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = 0.0, 0.0005, 0.0005, 0.0007, 0.0005, 0.0005, 0.0009, 0.00075, 0.0005, 1.0, 1.0, 1.0, 1.0 
   !Config Help  = 
   !Config Units = 
   CALL getin_p("DECL_FACTOR",decl_factor)

   !Config Key   = OPT_FACTOR
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0
   !Config Help  = 
   !Config Units = 
   !CALL getin_p("OPT_FACTOR",opt_factor)

   !Config Key   = COPPICE_DIAMETER
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = undef, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("COPPICE_DIAMETER",coppice_diameter)

   !Config Key   = SHOOTS_PER_STOOL
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = undef, 6, 6, 6, 6, 6, 6, 6, 6, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("SHOOTS_PER_STOOL",shoots_per_stool)

   !Config Key   = SRC_ROT_LENGTH
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = undef, 3, 3, 3, 3, 3, 3, 3, 3, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("SRC_ROT_LENGTH",src_rot_length)

   !Config Key   = SRC_NROTS
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = undef, 10, 10, 10, 10, 10, 10, 10, 10, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("SRC_NROTS",src_nrots)

   !Config Key   = M_DV
   !Config Desc  = 
   !Config if    = FOREST_MANAGEMENT 
   !Config Def   = undef, 1.05, 1.05, 1.05, 1.05, 1.05, 1.05, 1.05, 1.05, 1.05, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("M_DV",m_dv)

   !Config Key   = DELEUZE_A
   !Config Desc  = intercept of the intra-tree competition within a stand
   !               based on the competion rule of Deleuze and Dhote 2004
   !               Used when n_circ > 6
   !Config if    = OK_STOMATE, functional allocation 
   !Config Def   = undef, 0.23, 0.23, 0.23, 0.23, 0.23, 0.23, 0.23, 0.23, 0.23, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("DELEUZE_A",deleuze_a)

   !Config Key   = DELEUZE_B
   !Config Desc  = slope of the intra-tree competition within a stand
   !               based on the competion rule of Deleuze and Dhote 2004
   !               Used when n_circ > 6
   !Config if    = OK_STOMATE, functional allocation  
   !Config Def   = undef, 0.58, 0.58, 0.58, 0.58, 0.58, 0.58, 0.58, 0.58, 0.58, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("DELEUZE_B",deleuze_b)

   !Config Key   = DELEUZE_P_ALL
   !Config Desc  = Percentile of the circumferences that receives photosynthates
   !               based on the competion rule of Deleuze and Dhote 2004
   !               Used when n_circ < 6 for FM 1, FM2 and FM4
   !Config if    = OK_STOMATE, functional allocation  
   !Config Def   = undef, 0.5, 0.5, 0.99, 0.99, 0.99, 0.99, 0.99, 0.99, 0.99, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("DELEUZE_P_ALL",deleuze_p_all)

   !Config Key   = DELEUZE_P_COPPICE
   !Config Desc  = Percentile of the circumferences that receives photosynthates
   !               based on the competion rule of Deleuze and Dhote 2004
   !               Used when n_circ < 6 for FM3
   !Config if    = OK_STOMATE, functional allocation  
   !Config Def   = undef, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, undef, undef, undef, undef
   !Config Help  = 
   !Config Units = 
   CALL getin_p("DELEUZE_P_COPPICE",deleuze_p_coppice)

 END SUBROUTINE config_forest_manage_pft_parameters

!! ================================================================================================================================
!! SUBROUTINE   : pft_parameters_clear
!!
!>\BRIEF         This subroutine deallocates memory at the end of the simulation. 
!!
!! DESCRIPTION  : None
!!
!! RECENT CHANGE(S): None
!!
!! MAIN OUTPUT VARIABLE(S): None
!!
!! REFERENCE(S) : None
!!
!! FLOWCHART    : None
!! \n
!_ ================================================================================================================================

 SUBROUTINE pft_parameters_clear
   
   l_first_pft_parameters = .TRUE.
   
   IF (ALLOCATED(pft_to_mtc)) DEALLOCATE(pft_to_mtc)
   IF (ALLOCATED(PFT_name)) DEALLOCATE(PFT_name)
   IF (ALLOCATED(veget_ori_fixed_test_1)) DEALLOCATE(veget_ori_fixed_test_1)   
   IF (ALLOCATED(llaimax)) DEALLOCATE(llaimax)
   IF (ALLOCATED(llaimin)) DEALLOCATE(llaimin)
   IF (ALLOCATED(height_presc)) DEALLOCATE(height_presc)   
   IF (ALLOCATED(type_of_lai)) DEALLOCATE(type_of_lai)
   IF (ALLOCATED(is_tree)) DEALLOCATE(is_tree)
   IF (ALLOCATED(natural)) DEALLOCATE(natural)
   IF (ALLOCATED(is_deciduous)) DEALLOCATE(is_deciduous)
    IF (ALLOCATED(is_tropical)) DEALLOCATE(is_tropical)
   IF (ALLOCATED(is_temperate)) DEALLOCATE(is_temperate)
   IF (ALLOCATED(is_boreal)) DEALLOCATE(is_boreal)
   IF (ALLOCATED(is_evergreen)) DEALLOCATE(is_evergreen)
   IF (ALLOCATED(is_needleleaf)) DEALLOCATE(is_needleleaf)
   IF (ALLOCATED(is_tropical)) DEALLOCATE(is_tropical)
   IF (ALLOCATED(humcste)) DEALLOCATE(humcste)
   IF (ALLOCATED(pref_soil_veg)) DEALLOCATE(pref_soil_veg)
   IF (ALLOCATED(agec_group)) DEALLOCATE(agec_group)
   IF (ALLOCATED(start_index)) DEALLOCATE(start_index)
   IF (ALLOCATED(nagec_pft)) DEALLOCATE(nagec_pft)
   IF (ALLOCATED(is_c4)) DEALLOCATE(is_c4)  
   IF (ALLOCATED(vcmax_fix)) DEALLOCATE(vcmax_fix)
   IF (ALLOCATED(E_KmC)) DEALLOCATE(E_KmC)
   IF (ALLOCATED(E_KmO)) DEALLOCATE(E_KmO)
   IF (ALLOCATED(E_gamma_star)) DEALLOCATE(E_gamma_star)
   IF (ALLOCATED(E_Vcmax)) DEALLOCATE(E_Vcmax)
   IF (ALLOCATED(E_Jmax)) DEALLOCATE(E_Jmax)
   IF (ALLOCATED(aSV)) DEALLOCATE(aSV)
   IF (ALLOCATED(bSV)) DEALLOCATE(bSV)
   IF (ALLOCATED(tphoto_min)) DEALLOCATE(tphoto_min)
   IF (ALLOCATED(tphoto_max)) DEALLOCATE(tphoto_max)
   IF (ALLOCATED(aSJ)) DEALLOCATE(aSJ)
   IF (ALLOCATED(bSJ)) DEALLOCATE(bSJ)
   IF (ALLOCATED(D_Vcmax)) DEALLOCATE(D_Vcmax)
   IF (ALLOCATED(D_Jmax)) DEALLOCATE(D_Jmax)
   IF (ALLOCATED(E_Rd)) DEALLOCATE(E_Rd)
   IF (ALLOCATED(Vcmax25)) DEALLOCATE(Vcmax25)
   IF (ALLOCATED(arJV)) DEALLOCATE(arJV)
   IF (ALLOCATED(brJV)) DEALLOCATE(brJV)
   IF (ALLOCATED(KmC25)) DEALLOCATE(KmC25)
   IF (ALLOCATED(KmO25)) DEALLOCATE(KmO25)
   IF (ALLOCATED(gamma_star25)) DEALLOCATE(gamma_star25)
   IF (ALLOCATED(a1)) DEALLOCATE(a1)
   IF (ALLOCATED(b1)) DEALLOCATE(b1)
   IF (ALLOCATED(g0)) DEALLOCATE(g0)
   IF (ALLOCATED(h_protons)) DEALLOCATE(h_protons)
   IF (ALLOCATED(fpsir)) DEALLOCATE(fpsir)
   IF (ALLOCATED(fQ)) DEALLOCATE(fQ)
   IF (ALLOCATED(fpseudo)) DEALLOCATE(fpseudo)
   IF (ALLOCATED(kp)) DEALLOCATE(kp)
   IF (ALLOCATED(alpha)) DEALLOCATE(alpha)
   IF (ALLOCATED(gbs)) DEALLOCATE(gbs)
   IF (ALLOCATED(theta)) DEALLOCATE(theta)
   IF (ALLOCATED(alpha_LL)) DEALLOCATE(alpha_LL)
   IF (ALLOCATED(downregulation_co2_coeff)) DEALLOCATE(downregulation_co2_coeff) 
   IF (ALLOCATED(ext_coeff)) DEALLOCATE(ext_coeff)
   IF (ALLOCATED(rveg_pft)) DEALLOCATE(rveg_pft)
   IF (ALLOCATED(rstruct_const)) DEALLOCATE(rstruct_const)
   IF (ALLOCATED(kzero)) DEALLOCATE(kzero)
   IF (ALLOCATED(wmax_veg)) DEALLOCATE(wmax_veg)
   IF (ALLOCATED(throughfall_by_pft)) DEALLOCATE(throughfall_by_pft)
   IF (ALLOCATED(snowa_aged)) DEALLOCATE(snowa_aged)
   IF (ALLOCATED(snowa_dec)) DEALLOCATE(snowa_dec)
   IF (ALLOCATED(alb_leaf_vis)) DEALLOCATE(alb_leaf_vis)
   IF (ALLOCATED(alb_leaf_nir)) DEALLOCATE(alb_leaf_nir)   
   IF (ALLOCATED(leaf_ssa)) DEALLOCATE(leaf_ssa)   
   IF (ALLOCATED(leaf_psd)) DEALLOCATE(leaf_psd)   
   IF (ALLOCATED(bgd_reflectance)) DEALLOCATE(bgd_reflectance)
   IF (ALLOCATED(leaf_to_shoot_clumping)) DEALLOCATE(leaf_to_shoot_clumping) 
   IF (ALLOCATED(tune_coupled)) DEALLOCATE (tune_coupled)  
   IF (ALLOCATED(lai_correction_factor)) DEALLOCATE(lai_correction_factor) 
   IF (ALLOCATED(min_level_sep)) DEALLOCATE(min_level_sep)
   IF (ALLOCATED(lai_top)) DEALLOCATE(lai_top)
   IF (ALLOCATED(em_factor_isoprene)) DEALLOCATE(em_factor_isoprene)
   IF (ALLOCATED(em_factor_monoterpene)) DEALLOCATE(em_factor_monoterpene)
   IF (ALLOCATED(em_factor_ORVOC)) DEALLOCATE(em_factor_ORVOC)
   IF (ALLOCATED(em_factor_OVOC)) DEALLOCATE(em_factor_OVOC)
   IF (ALLOCATED(em_factor_MBO)) DEALLOCATE(em_factor_MBO)
   IF (ALLOCATED(em_factor_methanol)) DEALLOCATE(em_factor_methanol)
   IF (ALLOCATED(em_factor_acetone)) DEALLOCATE(em_factor_acetone)
   IF (ALLOCATED(em_factor_acetal)) DEALLOCATE(em_factor_acetal)
   IF (ALLOCATED(em_factor_formal)) DEALLOCATE(em_factor_formal)
   IF (ALLOCATED(em_factor_acetic)) DEALLOCATE(em_factor_acetic)
   IF (ALLOCATED(em_factor_formic)) DEALLOCATE(em_factor_formic)
   IF (ALLOCATED(em_factor_no_wet)) DEALLOCATE(em_factor_no_wet)
   IF (ALLOCATED(em_factor_no_dry)) DEALLOCATE(em_factor_no_dry)
   IF (ALLOCATED(Larch)) DEALLOCATE(Larch)
   IF (ALLOCATED(leaf_tab)) DEALLOCATE(leaf_tab)
   IF (ALLOCATED(sla)) DEALLOCATE(sla)
!!$   IF (ALLOCATED(tphoto_min_a)) DEALLOCATE(tphoto_min_a)
!!$   IF (ALLOCATED(tphoto_min_b)) DEALLOCATE(tphoto_min_b)
!!$   IF (ALLOCATED(tphoto_min_c)) DEALLOCATE(tphoto_min_c)
!!$   IF (ALLOCATED(tphoto_opt_a)) DEALLOCATE(tphoto_opt_a)
!!$   IF (ALLOCATED(tphoto_opt_b)) DEALLOCATE(tphoto_opt_b)
!!$   IF (ALLOCATED(tphoto_opt_c)) DEALLOCATE(tphoto_opt_c)
!!$   IF (ALLOCATED(tphoto_max_a)) DEALLOCATE(tphoto_max_a)
!!$   IF (ALLOCATED(tphoto_max_b)) DEALLOCATE(tphoto_max_b)
!!$   IF (ALLOCATED(tphoto_max_c)) DEALLOCATE(tphoto_max_c)
   IF (ALLOCATED(S0)) DEALLOCATE(S0)
   IF (ALLOCATED(L0)) DEALLOCATE(L0)
   IF (ALLOCATED(maint_resp_slope)) DEALLOCATE(maint_resp_slope)
   IF (ALLOCATED(maint_resp_slope_c)) DEALLOCATE(maint_resp_slope_c)
   IF (ALLOCATED(maint_resp_slope_b)) DEALLOCATE(maint_resp_slope_b)
   IF (ALLOCATED(maint_resp_slope_a)) DEALLOCATE(maint_resp_slope_a)
   IF (ALLOCATED(coeff_maint_zero)) DEALLOCATE(coeff_maint_zero)
   IF (ALLOCATED(cm_zero_leaf)) DEALLOCATE(cm_zero_leaf)
   IF (ALLOCATED(cm_zero_sapabove)) DEALLOCATE(cm_zero_sapabove)
   IF (ALLOCATED(cm_zero_sapbelow)) DEALLOCATE(cm_zero_sapbelow)
   IF (ALLOCATED(cm_zero_heartabove)) DEALLOCATE(cm_zero_heartabove)
   IF (ALLOCATED(cm_zero_heartbelow)) DEALLOCATE(cm_zero_heartbelow)
   IF (ALLOCATED(cm_zero_root)) DEALLOCATE(cm_zero_root)
   IF (ALLOCATED(cm_zero_fruit)) DEALLOCATE(cm_zero_fruit)
   IF (ALLOCATED(cm_zero_carbres)) DEALLOCATE(cm_zero_carbres)
   IF (ALLOCATED(cm_zero_labile)) DEALLOCATE(cm_zero_labile)
   IF (ALLOCATED(coeff_maint_init)) DEALLOCATE(coeff_maint_init)
   IF (ALLOCATED(frac_growthresp)) DEALLOCATE(frac_growthresp)
   IF (ALLOCATED(gpp_to_labile)) DEALLOCATE(gpp_to_labile)
   IF (ALLOCATED(pipe_density)) DEALLOCATE(pipe_density)
   IF (ALLOCATED(pipe_tune1)) DEALLOCATE(pipe_tune1)
   IF (ALLOCATED(pipe_tune2)) DEALLOCATE(pipe_tune2)
   IF (ALLOCATED(pipe_tune3)) DEALLOCATE(pipe_tune3)
   IF (ALLOCATED(pipe_tune4)) DEALLOCATE(pipe_tune4)
   IF (ALLOCATED(tree_ff)) DEALLOCATE(tree_ff)
   IF (ALLOCATED(pipe_k1)) DEALLOCATE(pipe_k1)
   IF (ALLOCATED(pipe_tune_exp_coeff)) DEALLOCATE(pipe_tune_exp_coeff)
   IF (ALLOCATED(mass_ratio_heart_sap)) DEALLOCATE(mass_ratio_heart_sap)
   IF (ALLOCATED(lai_to_height)) DEALLOCATE(lai_to_height)
   IF (ALLOCATED(canopy_cover)) DEALLOCATE(canopy_cover)
   IF (ALLOCATED(nmaxtrees)) DEALLOCATE(nmaxtrees)
   IF (ALLOCATED(height_init_min)) DEALLOCATE(height_init_min)
   IF (ALLOCATED(height_init_max)) DEALLOCATE(height_init_max)
   IF (ALLOCATED(alpha_self_thinning)) DEALLOCATE(alpha_self_thinning)
   IF (ALLOCATED(beta_self_thinning)) DEALLOCATE(beta_self_thinning)
   IF (ALLOCATED(fuelwood_diameter)) DEALLOCATE(fuelwood_diameter)
   IF (ALLOCATED(coppice_kill_be_wood)) DEALLOCATE(coppice_kill_be_wood)
   IF (ALLOCATED(cn_leaf_prescribed)) DEALLOCATE(cn_leaf_prescribed)
   IF (ALLOCATED(fcn_wood)) DEALLOCATE(fcn_wood)
   IF (ALLOCATED(fcn_root)) DEALLOCATE(fcn_root)
   IF (ALLOCATED(k_latosa_max)) DEALLOCATE(k_latosa_max)
   IF (ALLOCATED(k_latosa_min)) DEALLOCATE(k_latosa_min)
   IF (ALLOCATED(fruit_alloc)) DEALLOCATE(fruit_alloc) 
   IF (ALLOCATED(lai_max_to_happy)) DEALLOCATE(lai_max_to_happy)
   IF (ALLOCATED(flam)) DEALLOCATE(flam)
   IF (ALLOCATED(k_root)) DEALLOCATE(k_root)
   IF (ALLOCATED(k_sap)) DEALLOCATE(k_sap)
   IF (ALLOCATED(k_leaf)) DEALLOCATE(k_leaf)
   IF (ALLOCATED(phi_leaf)) DEALLOCATE(phi_leaf)
   IF (ALLOCATED(phi_50)) DEALLOCATE(phi_50)
   IF (ALLOCATED(c_cavitation)) DEALLOCATE(c_cavitation)
   IF (ALLOCATED(phi_soil_tune)) DEALLOCATE(phi_soil_tune)
   IF (ALLOCATED(lai_happy)) DEALLOCATE(lai_happy)
!-----------------------------------------------------------------------
!tzjh hydraulic architecture

   IF (ALLOCATED(gpsi)) DEALLOCATE(gpsi)
   IF (ALLOCATED(gpsi_50)) DEALLOCATE(gpsi_50)
   IF (ALLOCATED(gmax)) DEALLOCATE(gmax)
   IF (ALLOCATED(gmin)) DEALLOCATE(gmin)
   IF (ALLOCATED(kmax_leaf)) DEALLOCATE(kmax_leaf)
   IF (ALLOCATED(kmax_stem)) DEALLOCATE(kmax_stem)
   IF (ALLOCATED(kmax_root)) DEALLOCATE(kmax_root)
   IF (ALLOCATED(a_leaf)) DEALLOCATE(a_leaf)
   IF (ALLOCATED(a_stem)) DEALLOCATE(a_stem)
   IF (ALLOCATED(a_root)) DEALLOCATE(a_root)
   IF (ALLOCATED(P50_leaf)) DEALLOCATE(P50_leaf)
   IF (ALLOCATED(P50_stem)) DEALLOCATE(P50_stem)
   IF (ALLOCATED(P50_root)) DEALLOCATE(P50_root)
   IF (ALLOCATED(wood_density)) DEALLOCATE(wood_density)
   IF (ALLOCATED(w_density_stem)) DEALLOCATE(w_density_stem)
   IF (ALLOCATED(root_shoot_ratio)) DEALLOCATE(root_shoot_ratio)
   IF (ALLOCATED(rwc_root)) DEALLOCATE(rwc_root)
   IF (ALLOCATED(root_density)) DEALLOCATE(root_density)
   IF (ALLOCATED(LDMC)) DEALLOCATE(LDMC)
   IF (ALLOCATED(sla_hydro)) DEALLOCATE(sla_hydro)
   IF (ALLOCATED(cxyl)) DEALLOCATE(cxyl)
   IF (ALLOCATED(cr)) DEALLOCATE(cr)
   IF (ALLOCATED(cl)) DEALLOCATE(cl)

!-----------------------------------------------------------------------

   IF (ALLOCATED(tune_reserves_in_sapling)) DEALLOCATE(tune_reserves_in_sapling)
   IF (ALLOCATED(death_distribution_factor)) DEALLOCATE(death_distribution_factor)
   IF (ALLOCATED(npp_reset_value)) DEALLOCATE(npp_reset_value)
   IF (ALLOCATED(resist)) DEALLOCATE(resist)
   IF (ALLOCATED(coeff_lcchange_s)) DEALLOCATE(coeff_lcchange_s)
   IF (ALLOCATED(coeff_lcchange_m)) DEALLOCATE(coeff_lcchange_m)
   IF (ALLOCATED(coeff_lcchange_l)) DEALLOCATE(coeff_lcchange_l)
   IF (ALLOCATED(lai_max)) DEALLOCATE(lai_max)
   IF (ALLOCATED(pheno_model)) DEALLOCATE(pheno_model)
   IF (ALLOCATED(pheno_type)) DEALLOCATE(pheno_type)
   IF (ALLOCATED(pheno_gdd_crit_c)) DEALLOCATE(pheno_gdd_crit_c)
   IF (ALLOCATED(pheno_gdd_crit_b)) DEALLOCATE(pheno_gdd_crit_b)
   IF (ALLOCATED(pheno_gdd_crit_a)) DEALLOCATE(pheno_gdd_crit_a)
   IF (ALLOCATED(pheno_gdd_crit)) DEALLOCATE(pheno_gdd_crit)
   IF (ALLOCATED(ngd_crit)) DEALLOCATE(ngd_crit)
   IF (ALLOCATED(opti_kpheno_crit)) DEALLOCATE(opti_kpheno_crit)
   IF (ALLOCATED(ncdgdd_temp)) DEALLOCATE(ncdgdd_temp)
   IF (ALLOCATED(hum_frac)) DEALLOCATE(hum_frac)
   IF (ALLOCATED(hum_min_time)) DEALLOCATE(hum_min_time)
   IF (ALLOCATED(tau_sap)) DEALLOCATE(tau_sap)
   IF (ALLOCATED(tau_fruit)) DEALLOCATE(tau_fruit)
   IF (ALLOCATED(tau_root)) DEALLOCATE(tau_root)
   IF (ALLOCATED(tau_leaf)) DEALLOCATE(tau_leaf)
   IF (ALLOCATED(ecureuil)) DEALLOCATE(ecureuil)
   IF (ALLOCATED(alloc_min)) DEALLOCATE(alloc_min)
   IF (ALLOCATED(alloc_max)) DEALLOCATE(alloc_max)
   IF (ALLOCATED(demi_alloc)) DEALLOCATE(demi_alloc)
   IF (ALLOCATED(leaffall)) DEALLOCATE(leaffall)
   IF (ALLOCATED(senescence_type)) DEALLOCATE(senescence_type)
   IF (ALLOCATED(senescence_hum)) DEALLOCATE(senescence_hum)
   IF (ALLOCATED(nosenescence_hum)) DEALLOCATE(nosenescence_hum)
   IF (ALLOCATED(max_turnover_time)) DEALLOCATE(max_turnover_time)
   IF (ALLOCATED(min_turnover_time)) DEALLOCATE(min_turnover_time)
   IF (ALLOCATED(min_leaf_age_for_senescence)) DEALLOCATE(min_leaf_age_for_senescence)
   IF (ALLOCATED(senescence_temp_c)) DEALLOCATE(senescence_temp_c)
   IF (ALLOCATED(senescence_temp_b)) DEALLOCATE(senescence_temp_b)
   IF (ALLOCATED(senescence_temp_a)) DEALLOCATE(senescence_temp_a)
   IF (ALLOCATED(senescence_temp)) DEALLOCATE(senescence_temp)
   IF (ALLOCATED(gdd_senescence)) DEALLOCATE(gdd_senescence)
   IF (ALLOCATED(residence_time)) DEALLOCATE(residence_time)
   ! added by yitong yao 07 Jan 2020 08:30 
   IF (ALLOCATED(plc_kill_frac)) DEALLOCATE(plc_kill_frac)
   ! added by yitong yao 07 Jan 2020 08:30
   IF (ALLOCATED(mor_kill_frac)) DEALLOCATE(mor_kill_frac)
   IF (ALLOCATED(tmin_crit)) DEALLOCATE(tmin_crit)
   IF (ALLOCATED(tcm_crit)) DEALLOCATE(tcm_crit)
   IF (ALLOCATED(mortality_min)) DEALLOCATE(mortality_min)
   IF (ALLOCATED(mortality_max)) DEALLOCATE(mortality_max)
   IF (ALLOCATED(ref_mortality)) DEALLOCATE(ref_mortality)
   IF (ALLOCATED(tau_hum_growingseason)) DEALLOCATE(tau_hum_growingseason)
   IF (ALLOCATED(lai_initmin)) DEALLOCATE(lai_initmin)
   IF (ALLOCATED(bm_sapl_old)) DEALLOCATE(bm_sapl_old)
   IF (ALLOCATED(migrate)) DEALLOCATE(migrate)
   IF (ALLOCATED(maxdia)) DEALLOCATE(maxdia)
   IF (ALLOCATED(cn_sapl)) DEALLOCATE(cn_sapl)
   IF (ALLOCATED(leaf_timecst)) DEALLOCATE(leaf_timecst)
   IF (ALLOCATED(plantation)) DEALLOCATE(plantation)
   IF (ALLOCATED(fm_allo_a)) DEALLOCATE(fm_allo_a)
   IF (ALLOCATED(fm_allo_c)) DEALLOCATE(fm_allo_c)
   IF (ALLOCATED(fm_allo_d)) DEALLOCATE(fm_allo_d)
   IF (ALLOCATED(fm_allo_p)) DEALLOCATE(fm_allo_p)
   IF (ALLOCATED(fm_allo_q)) DEALLOCATE(fm_allo_q)
   IF (ALLOCATED(allo_crown_a0)) DEALLOCATE(allo_crown_a0)
   IF (ALLOCATED(allo_crown_a1)) DEALLOCATE(allo_crown_a1)
   IF (ALLOCATED(allo_crown_a2)) DEALLOCATE(allo_crown_a2)
   IF (ALLOCATED(h_first)) DEALLOCATE(h_first)
   IF (ALLOCATED(dens_target)) DEALLOCATE(dens_target)
   IF (ALLOCATED(thinstrat)) DEALLOCATE(thinstrat)
   IF (ALLOCATED(taumin)) DEALLOCATE(taumin)
   IF (ALLOCATED(taumax)) DEALLOCATE(taumax)
   IF (ALLOCATED(alpha_rdi_upper)) DEALLOCATE(alpha_rdi_upper)
   IF (ALLOCATED(beta_rdi_upper)) DEALLOCATE(beta_rdi_upper)
   IF (ALLOCATED(alpha_rdi_lower)) DEALLOCATE(alpha_rdi_lower)
   IF (ALLOCATED(beta_rdi_lower)) DEALLOCATE(beta_rdi_lower)
   IF (ALLOCATED(largest_tree_dia)) DEALLOCATE(largest_tree_dia)
   IF (ALLOCATED(branch_ratio)) DEALLOCATE(branch_ratio)
   IF (ALLOCATED(branch_ratio)) DEALLOCATE(branch_ratio)
   IF (ALLOCATED(decl_factor)) DEALLOCATE(decl_factor)
   !IF (ALLOCATED(opt_factor)) DEALLOCATE(opt_factor)
   IF (ALLOCATED(coppice_diameter)) DEALLOCATE(coppice_diameter)
   IF (ALLOCATED(shoots_per_stool)) DEALLOCATE(shoots_per_stool)
   IF (ALLOCATED(src_rot_length)) DEALLOCATE(src_rot_length)
   IF (ALLOCATED(src_nrots)) DEALLOCATE(src_nrots)
   IF (ALLOCATED(m_dv)) DEALLOCATE(m_dv)
   IF (ALLOCATED(recruitment_light_threshold)) DEALLOCATE(recruitment_light_threshold)
   IF (ALLOCATED(dia_recr)) DEALLOCATE(dia_recr)
   IF (ALLOCATED(hei_recr)) DEALLOCATE(hei_recr)
   IF (ALLOCATED(harvest_ratio)) DEALLOCATE(harvest_ratio)
   
 END SUBROUTINE pft_parameters_clear

END MODULE pft_parameters
